//CMSLMALC JOB (accounting info),'ITSLM Allocation',
//       MSGLEVEL=(1,1),TIME=1,REGION=32M,NOTIFY=
//*******************************************************************
//*                                                                 *
//* Example JCL to allocate a ITSLM Environment Database and a      *
//* ITSLM Contract Database for use with ITSLM on z/OS.             *
//*                                                                 *
//* This job will do the following:                                 *
//*                                                                 *
//*     1) Delete the ITSLM Contract Database if it exists.  This   *
//*        makes the job re-runnable, in case of a failure.         *
//*                                                                 *
//*     2) Delete the ITSLM Environment Database if it exists.      *
//*        This makes the job re-runnable, in case of a failure.    *
//*                                                                 *
//*     3) Allocate the new ITSLM Contract Database.                *
//*                                                                 *
//*     4) Allocate the new ITSLM Environment Database.             *
//*                                                                 *
//*     5) Prime the new ITSLM Environment Database.                *
//*                                                                 *
//*     6) Prime the new ITSLM Contract Database.                   *
//*                                                                 *
//*=================================================================*
//*                                                                 *
//* This job requires the following customization:                  *
//*                                                                 *
//*  1) Change the JOB card to a valid job card for your system.    *
//*                                                                 *
//*  2) Do a global change of YOUR.NEWCDB to the high-level         *
//*     qualification you wish to use to name your ITSLM            *
//*     Contract Database.                                          *
//*                                                                 *
//*  3) Do a global change of YOUR.NEWENV to the name of your       *
//*     ITSLM Environment Database.                                 *
//*                                                                 *
//*  4) Verify the space requirements for the datasets on the       *
//*     ALLOC step.                                                 *
//*                                                                 *
//*  5) Do a global change of LRECL and BLKSIZE to valid            *
//*     parameters for your system.                                 *
//*     For DASD we recommend to set these values to half track     *
//*     size, which is, for instance, 23040 for a 3380 device,      *
//*     27648 for a 3390 device, and 22528 for a 9345 device.       *
//*                                                                 *
//*  6) Do a global change of UNIT=SYSDA to a valid UNIT=           *
//*     parameter for your system.                                  *
//*                                                                 *
//*  7) Do a global change of <volume> to a valid VOL=SER=          *
//*     parameter for your system.                                  *
//*                                                                 *
//*  8) Verify the invocation of SAS in the //SETUP step is         *
//*     appropriate for your system.                                *
//*                                                                 *
//*  9) Do a global change of YOUR.ITRM to the high-level           *
//*     qualifier of SAS IT Resource Management software on your    *
//*     z/OS system.  In particular make sure this qualifier has    *
//*     been set correctly for the CONFIG parameter in step SETUP.  *
//*                                                                 *
//*  NOTE:  If you increase the size of any of the libraries DAY,   *
//*         WEEK, MONTH, YEAR, or DETAIL, increase the size of the  *
//*         ADMIN library by the same amount.                       *
//*                                                                 *
//*******************************************************************
//*                                                                **
//*   Delete the ITSLM Contract Database and ITSLM Environment     **
//*   Database if they exist.                                      **
//*                                                                **
//*******************************************************************
//CLEANUP EXEC PGM=IDCAMS
//SYSPRINT DD DUMMY
//SYSIN    DD DATA,DLM='$$'
  DELETE 'YOUR.NEWCDB.DETAIL'
  DELETE 'YOUR.NEWCDB.DAY'
  DELETE 'YOUR.NEWCDB.WEEK'
  DELETE 'YOUR.NEWCDB.MONTH'
  DELETE 'YOUR.NEWCDB.YEAR'
  DELETE 'YOUR.NEWCDB.DICTLIB'
  DELETE 'YOUR.NEWCDB.PDBWORK'
  DELETE 'YOUR.NEWCDB.ADMIN'
  DELETE 'YOUR.NEWCDB.COLLECT'
  DELETE 'YOUR.NEWENV'
  SET MAXCC=0
$$
//*******************************************************************
//*                                                                **
//*   Allocate the libraries for the new ITSLM Contract Database   **
//*   and the ITSLM Environment Database.                          **
//*                                                                **
//*******************************************************************
//ALLOC   EXEC PGM=IEFBR14
//DETAIL   DD DSN=YOUR.NEWCDB.DETAIL,DISP=(NEW,CATLG,DELETE),
//            DCB=(LRECL=27648,BLKSIZE=27648,RECFM=FS),
//            SPACE=(CYL,(20,10)),UNIT=SYSDA,VOL=SER=<volume>
//DAY      DD DSN=YOUR.NEWCDB.DAY,DISP=(NEW,CATLG,DELETE),
//            DCB=(LRECL=27648,BLKSIZE=27648,RECFM=FS),
//            SPACE=(CYL,(20,10)),UNIT=SYSDA,VOL=SER=<volume>
//WEEK     DD DSN=YOUR.NEWCDB.WEEK,DISP=(NEW,CATLG,DELETE),
//            DCB=(LRECL=27648,BLKSIZE=27648,RECFM=FS),
//            SPACE=(CYL,(25,2)),UNIT=SYSDA,VOL=SER=<volume>
//MONTH    DD DSN=YOUR.NEWCDB.MONTH,DISP=(NEW,CATLG,DELETE),
//            DCB=(LRECL=27648,BLKSIZE=27648,RECFM=FS),
//            SPACE=(CYL,(5,2)),UNIT=SYSDA,VOL=SER=<volume>
//YEAR     DD DSN=YOUR.NEWCDB.YEAR,DISP=(NEW,CATLG,DELETE),
//            DCB=(LRECL=27648,BLKSIZE=27648,RECFM=FS),
//            SPACE=(CYL,(1,1)),UNIT=SYSDA,VOL=SER=<volume>
//DICTLIB  DD DSN=YOUR.NEWCDB.DICTLIB,DISP=(NEW,CATLG,DELETE),
//            DCB=(LRECL=6144,BLKSIZE=6144,RECFM=FS),
//            SPACE=(CYL,(5,5)),UNIT=SYSDA,VOL=SER=<volume>
//PDBWORK  DD DSN=YOUR.NEWCDB.PDBWORK,DISP=(NEW,CATLG,DELETE),
//            DCB=(LRECL=27648,BLKSIZE=27648,RECFM=FS),
//            SPACE=(CYL,(20,10)),UNIT=SYSDA,VOL=SER=<volume>
//ADMIN    DD DSN=YOUR.NEWCDB.ADMIN,DISP=(NEW,CATLG,DELETE),
//            DCB=(LRECL=27648,BLKSIZE=27648,RECFM=FS),
//            SPACE=(CYL,(80,25)),UNIT=SYSDA,VOL=SER=<volume>
//COLLECT  DD DSN=YOUR.NEWCDB.COLLECT,DISP=(NEW,CATLG,DELETE),
//            DCB=(LRECL=27648,BLKSIZE=27648,RECFM=FS),
//            SPACE=(CYL,(5,2)),UNIT=SYSDA,VOL=SER=<volume>
//SLMENV   DD DSN=YOUR.NEWENV,DISP=(NEW,CATLG,DELETE),
//            DCB=(LRECL=27648,BLKSIZE=27648,RECFM=FS),
//            SPACE=(CYL,(5,2)),UNIT=SYSDA,VOL=SER=<volume>
//*******************************************************************
//*                                                                **
//*   Invoke SAS to prime the ITSLM Environment Database and the   **
//*   ITSLM Contract Database.                                     **
//*                                                                **
//*******************************************************************
//SETUP  EXEC SAS,CONFIG='YOUR.ITRM.CPMISC(CMCONFIG)'
//SLM     DD DSN=*.ALLOC.SLMENV,DISP=OLD
//SYSIN   DD DATA,DLM='$$'

   %CPSTART(MODE=BATCH,
            DISP=OLD,
            PDB=YOUR.NEWCDB.,
            ROOT=YOUR.ITRM.);
   filename SLMINIT catalog 'pgmlib.slmenv.environment_init.source' ;
   %inc SLMINIT;
   filename SLMINIT clear;

   %global CPSLMENV_SCHEMA_VERSION;
   proc sql noprint;
      select version into :CPSLMENV_SCHEMA_VERSION
      from slm.environment;
   quit;


   data dictlib.slmenv(label=
        'IT SLM environment database back reference');
     attrib envDBPath
            length=$200
            label='Path of environment database';
     attrib contractID
            length=8
            label='Contract node object id';
     attrib contractCreationDT
            length=$30
            label='Contract database creation datetime string';
     attrib schemaVersion
            length=8
            label='Contract database software schema version';
     envDBPath = pathname('slm');
     contractID= -1;
     contractCreationDT = 'Not yet created';
     schemaVersion = &CPSLMENV_SCHEMA_VERSION;
   run;

$$
//
