
 /*----------------------------------------------------------------------------
  |
  | Copyright (C) 2003 by SAS Institute Inc., Cary, NC 27513
  |
  | ---------------------------------------------------------------------------
  | CPSLMRPT: SAS (R) IT Service Level Management program for producing
  | daily reports in batch mode.
  |
  | This program is named cpslmrpt.sas on Windows and UNIX and CPSLMRPT on
  | z/OS. This program produces two types of reports, a set of HTML based
  | drilldown reports and a gallery of graph reports. Read all the instructions
  | and comments below for details and customization instructions before running
  | any of the reports below.
  |
  | Schedule this batch job to run every day after your ETL process completes.
  | The gallery reports require datasets in the ADMIN level or your contract
  | database that are created by the ETL process. These reports call various
  | report macros, such as %CPPLOT1 and %CPPLOT2, %CPSPEC, and %CPCHART to
  | generate the actual graphs. Please refer to the SAS IT Resource Management
  | Macro Reference Guide for more information about these macros.
  |
  | BEFORE YOU RUN THIS PROGRAM:
  |
  | Please read all of the comments in this report batch job before you
  | begin customization and before you submit this program.
  |
  | TO RUN THIS PROGRAM:
  |
  | 1.  After you have read all of the comments in this batch job, search for
  |     all occurrences of the keyword CUSTOMIZE below and make the required,
  |     Recommended, and Optional customizations to this program. (At each
  |     occurrence, there is a description of what to change.) There are a
  |     few required changes. These have the keyword (Required). The Recommended
  |     changes offer suggestions for enhancing your reports and or for enabling
  |     or disabling the generation of the reports. These have the keyword
  |     (Recommended). The optional changes are provided for your information.
  |     These have the keyword (Optional).
  |
  | 2.  Assure that all your ETL processes have completed before you submit
  |     this program.
  |
  | 3a. If your SLM server runs on Windows or UNIX, you can submit cpslmrpt.sas
  |     from the Windows or UNIX command line or from the SAS Program Editor
  |     window.
  |
  |        From the command line on Windows, use this command:
  |     sas.exe -sysin cpslmrpt.sas -icon -nosplash -noxwait
  |
  |        From the command line on UNIX, use this command:
  |     sas cpslmrpt.sas -noterminal -xrm 'SAS.startSessionManager:false'
  |
  |        From the SAS Program Editor window, type this command in the SAS
  |        command field:
  |     include fully-qualified-name-of-cpslmrpt.sas
  |        next press Enter, and then select Run -> Submit.
  |
  | 3b. If your SLM server runs on z/OS, find the batch job named CMSLMJCL
  |     (in the same CPMISC PDS where this program resides). Follow the
  |     customization instructions there for submitting this job.
  |
  | 4. Check the log every day after the job runs.
  |
  | 5. For each contract, a location for the reports was specified in the
  |    ITSLM administration client on the "Reports" tab for that contract.
  |    Ideally this location should be accessible from a web server.  Once
  |    you create reports, the starting point for viewing the drilldown reports
  |    is <CPSLMCRP>/main/index.htm, where <CPSLMCRP> is the location specified
  |    as the report location or the report URL for that contract.   To view
  |    the gallery reports for that contract, point a web browser to
  |    <CPSLMCRP>/welcome.htm.
  |
  | 6. To move the reports to another system, for example if you need to move
  |    them from z/OS HFS files to a UNIX or PC system, use a utility such
  |    as FTP to move the entire directory structure.
  |
  | NOTE:
  |  Some descriptions say to uncomment a macro statement if you want to
  |  include a program. To uncomment a macro statement, remove the asterisk.
  |  For example, the following statement is commented out (inactive):
  |       %*let ...;
  |  and the following statement is uncommented (active):
  |       %let ...;
  *--------------------------------------------------------------------------*/

 /*----------------------------------------------------------------------------
  | WEBSTYLE is the gallery style used by the gallery reports.
  *--------------------------------------------------------------------------*/
  %let WEBSTYLE = DYNAMIC;

 /*----------------------------------------------------------------------------
  | CUSTOMIZE:  (Optional)
  | GIFDEVICE is the device driver that is used for creating the large graph
  | reports. GIF733 produces a gif image whose size is 733x550 pixels. Valid
  | values for GIFDEVICE are GIF160, GIF260,  GIF373, GIF570, and GIF733.
  | JAVDEVICE is the device driver used for creating the large interactive
  | applet graphs. Currenlty, the only valid value for JAVADEVICE is JAVA.
  | If you do not want to create java applets, change the JAVADEVICE value
  | from JAVA to GIF733. Both are used by the gallery reports.
  *--------------------------------------------------------------------------*/
  %let GIFDEVICE = GIF733;
  %let JAVDEVICE = JAVA;

 /*----------------------------------------------------------------------------
  | CUSTOMIZE: (Recommended)
  | Read the following information about the variable APPLETLOC.
  |
  | Some gallery reports use the JAVA device driver to create large interactive
  | graphs. (These are the ones whose LARGEDEV option is set to JAVDEVICE.)
  | These applets must have access to the jar file, graphapp.jar to render
  | the report.
  |
  | To ensure that all browsers that will view Java applets have access to the
  | jar file needed to render the reports, we recommend that you copy the
  | jar file, graphapp.jar, to a location accessible via a URL and modify your
  | SAS configuration file to point to the new location. If you have not
  | already done so, follow the steps below.
  |
  |  1. Locate your graph applet jar file, graphapp.jar. You may find the jar
  |     file in one of several locations.
  |
  |     If you have an z/OS server, locate a copy of the jar file on your
  |     Client-Side Components CD. If you have a Windows or UNIX server,
  |     the jar file is automatically installed with your SAS installation.
  |     To determine the location of your jar file, submit the following code
  |     from your SAS program editor:
  |
  |              proc options option=appletloc;   run;
  |
  |     The current setting of this option will be displayed in the SAS log.
  |
  |     A later version of the jar file can also be found in the two locations
  |     below. This 9.0 version of the applet is compatible with SAS 8.2 and
  |     offers  some enhancements over the 8.2 version.
  |      a. If you installed Enterprise Guide, search for graphapp.jar in the
  |         shared directory,  <..\Shared Files\applets>.
  |      b. If you have access to your ITSLM Client CD, search for graphapp.jar
  |         in the directory, <..\samples\reports\web>.
  |
  |  2. Copy the jar file, graphapp.jar, to a common area, such as a URL
  |     that all browsers can access.
  |
  |  3. Locate your SAS configuration file and modify or add the appletloc
  |     option to point to the new location of the jar file. On windows and
  |     UNIX the file is named "SASV8.CFG" or "sasv8.cfg" in the same directory
  |     or folder where your SAS executable is located. on z/OS the file is
  |     named  "prefix.CONFIG", where prefix is the common prefix for all the
  |     data sets of the SAS installation. Change or add the appletloc option
  |     to specify a URL, such as:
  |
  |          -APPLETLOC "http://your/web/server/directory"
  |
  |  NOTE: If you want to override the applet location for this batch job
  |  only, uncomment the options statement below, by removing the asterisk,
  |  and set the value here. Setting the value here will override the value
  |  in the config file. Be sure the value points to a directory not the jar
  |  file itself.
  *--------------------------------------------------------------------------*/
  *options appletloc = "http://your/web/server/directory";

 /*----------------------------------------------------------------------------
  | Color is the background or frame color for the graph gallery reports.
  *--------------------------------------------------------------------------*/
  %let COLOR = CXFAF8ED;  /* light beige */



 /*----------------------------------------------------------------------------
  | This options turns off the byline that is generated in gallery reports
  | by default.
  *--------------------------------------------------------------------------*/
  options nobyline;

 /*----------------------------------------------------------------------------
  | CUSTOMIZE: (Required)
  | The SLM Environment Path variable is needed to connect to your SLM
  | environment and contract database:
  |
  | Set the slmEnvPath value to your SLM environment.
  | Note that the value below is set for a Windows server. Be sure to set your
  | value using the correct syntax for your operating system.
  |
  | Note:  If you are using a SAS/SHARE server to access your SLM environment,
  |        *and* the environment is allocated permanently to the SHARE server
  |        with a libref of SLM, then you should blank out the value for
  |        slmEnvPath, that is, the statement should look like:
  |        %let slmEnvPath=;
  |
  | UNIX:   %let slmEnvPath=/slm/environment;
  | z/OS:   %let slmEvnPath=SLM.ENVIRON;
  *--------------------------------------------------------------------------*/
  %let slmEnvPath=c:\slm\environment ;

 /*----------------------------------------------------------------------------
  | CUSTOMIZE: (Optional)
  | If you use a SAS/SHARE server to connect to your SLM environment to enable
  | concurrent access to the environment, then you must set the following
  | parameters.   slmShareService must be the server service name or port.
  | If the server requires authentication, you should specify the userid and
  | password to be used in slmShareUser and slmSharePassword, respectively.
  |
  *--------------------------------------------------------------------------*/
  %let slmShareService=;
  %let slmShareUser=;
  %let slmSharePassword;

 /*----------------------------------------------------------------------------
  | CUSTOMIZE: (Optional)
  | If you want to point your sasautos to a directory or path other than the
  | default installation path, you can uncomment and set the appropriate value
  | below. Note that the value below is set for an z/OS server. Be sure to
  | set your value using the correct syntax for your operating system.
  |
  | UNIX:    options sasautos = ("!sasroot\cpe\sasmacro" sasautos);
  | Windows: options sasautos = ("!sasroot/cpe/sasmacro" sasautos);
  *--------------------------------------------------------------------------*/
  *options sasautos = ("sasautoscpd.itsv27.mvsgpp.macros" sasautos);

 /*---------------------------------------------------------------------------
  | Global macro variables used by both gallery and drilldown reports.
  *--------------------------------------------------------------------------*/
  %global slmactives;
  %global cpslmcrp;
  %global slmrptdt;
  %global slmcpldir;
  %global slmcutoff;
  %global cpslmcid;
  %global id;

 /*----------------------------------------------------------------------------
  | The code below builds eleven macros: %RptInd, %RptScore, %RptARTScore,
  | %RptTarget, %DrillDown, %CreateDir, %InitDrill, %InitGallery,
  | %RptAllContracts, %RptOneContract, %RunReports. (Each macro build
  | is from %macro to %mend). Then, after all five macros are built, the program
  | code calls the macros, some with various parameter values. Refer to the
  | comments for each individual macro for more information about each macro.
  *--------------------------------------------------------------------------*/

 /*----------------------------------------------------------------------------
  | #1: This macro, %RptInd, generates Indicator reports in a web Gallery. It
  | produces Availability, Response Time, Throughput and Composite Indicator
  | reports, depending upon the parameter supplied to the macro. Valid calls
  | are:
  |
  |      %RptInd(Objective = availability);
  |      %RptInd(Objective = response);
  |      %RptInd(Objective = throughput);
  |      %RptInd(Objective = composite);
  |
  | Reports below include Hourly, Daily, Monthly, Worst, Best and Trend
  | Reports. This macro calls the macro %CPWEBINI to initialize the
  | directory before it runs the reports. It calls %CPIDTOPN to determine
  | the Top N and Bottom N nodes for reporting best and worst performers.
  *--------------------------------------------------------------------------*/
  %macro RptInd(Objective = );
  %let Objective = %lowcase(&Objective);

 /*----------------------------------------------------------------------------
  | Check Return code from %CPSLMCON before proceeding.
  *--------------------------------------------------------------------------*/
  %if &slmrc gt 0 %then %do;
      %put ************************************************************;
      %put ERROR: Database not active. Check your log for prior errors;
      %put ERROR: Indicator &Objective Reports Not Run;
      %put ************************************************************;
      %goto exit1;
  %end;

 /*----------------------------------------------------------------------------
  | Verify that CPSLMCRP exists before proceeding.
  *--------------------------------------------------------------------------*/
  %let SLMDIRCHK = %cpsep(&cpslmcrp)slm;
  %if (&CPOPSYS ne MVS) and (%sysfunc(fileexist(&SLMDIRCHK))=0) %then %do;
      %put ************************************************************;
      %put ERROR: &SLMDIRCHK Does not exist. Check your log for previous;
      %put ERROR: errors. ;
      %put ************************************************************;
      %goto exit1;
  %end;

 /*----------------------------------------------------------------------------
  | Set macro variables used by the Indicator Reports.
  |
  | The Indicator reports below can be Availability, Response Time, Throughput
  | or Composite reports. The Report name (CPRPTNM), titles, labels and
  | variables graphed depend on the parameter provided at macro invocation
  | time.
  |
  | CUSTOMIZE: (Optional)
  | There are a few macro variables defined below that you may choose to
  | modify for your site.
  | 1. Indfmt: This macro variable is used to format the indicator value.
  |    It is hard coded to 12.2 by default. You may change this value to any
  |    valid SAS graph format that makes sense for your data or use a BEST
  |    format, such as BEST12.2 to allow SAS graph to guess at a best format
  |    based on the data.
  | 2. best and worst: These macro variables are used to determine the
  |    numbers for the top and bottom performers. If you change the values
  |    be sure to preserve the sign.
  | CUSTOMIZE: (Recommended)
  | 3. colorlst and dvalues: Used by reports that report composite objectives.
  |    These variables are used in conjuction to determine the numeric grouping
  |    and legend of the data in the spectrum reports, called by the %CPSPEC
  |    macro. The default values of 1, 2, 3 and 4 and the colors used below
  |    can be changed to correspond to your composite scoring pattern.
  |
  |   These are the default colors:
  |   CXFAF8ED light beige for missing values
  |   CXCC0066 red
  |   CXFFCC00 yellow
  |   CX669966 green
  |   CX336699 blue
  |
  |   The default values for dvalues and colorlst below will generate
  |   a spectrum report with the following legend:
  |
  |      blue <= 1 ; green <= 2 ; yellow <= 3 ; red <= 4
  |
  |   These default values can be used with a scoring pattern where 1
  |   represents Excellent, 2 represents Good, 3 represents Fair and 4
  |   represents Poor.
  |
  |   Modify these values to match your scoring pattern. You may also add
  |   additional values. Be sure to add an additional color for each additional
  |   value that is added. Note that the extra color in the colorlst is beige,
  |   which is used for missing values.
  *--------------------------------------------------------------------------*/
  %if &Objective = availability %then %do;
          %let desc = Availability;
          %let type = AV;
          %let dirname = slmia;
          %let catname = slmia;
          %let IndVar = asli;
          %let TargetVar = atarget;
          %let TargetBas = atgtbas;
          %let best = 10;
          %let worst = -10;
          %let IndFmt = 12.2;
   %end;
   %else %if &Objective = response %then %do;
          %let desc = Response Time;
          %let type = RT;
          %let dirname = slmir;
          %let catname = slmir;
          %let IndVar = rsli;
          %let TargetVar = rtarget;
          %let TargetBas = rtgtbas;
          %let best = -10;
          %let worst = 10;
          %let IndFmt = 12.2;
   %end;
   %else %if &Objective = throughput %then %do;
          %let desc = Throughput;
          %let type = TH;
          %let dirname = slmit;
          %let catname = slmit;
          %let IndVar = tsli;
          %let TargetVar = ttarget;
          %let TargetBas = ttgtbas;
          %let best = 10;
          %let worst = -10;
          %let IndFmt = 12.2;
   %end;
   %else %if &Objective = composite %then %do;
          %let desc = Composite;
          %let type = CM;
          %let dirname = slmic;
          %let catname = slmic;
          %let IndVar = zsli;
          %let TargetVar = ztarget;
          %let TargetBas = ztgtbas;
          %let best = -10;
          %let worst = 10;
          %let IndFmt = 12.2;
          %let dvalues = 1 2 3 4;
          %let colorlst = CXFAF8ED CX336699 CX669966 CXFFCC00 CXCC0066;
   %end;
   %else %do;
          %put ***************************************************;
          %put ERROR: Valid parameters are;
          %put Availability, Response, Throughput and Composite;
          %put ***************************************************;
          %goto exit1;
   %end;

   /* do not force an abend in a z/OS batch job for a reporting error */
   options noerrorabend;

 /*----------------------------------------------------------------------------
  | %CPWEBINI initializes the directory, folder, or PDS before creating
  | the reports.
  *--------------------------------------------------------------------------*/
  %cpwebini(cat = work.&catname, dir = &cpslmcrp.&dirname,
      WEBSTYLE = &webstyle);

 /*----------------------------------------------------------------------------
  | Report name: INAVHR01 or INRTHR01 or INTHHR01 or INCMHR01
  | Description: Hourly Mean Indicator Plot
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.detail))ne 0) %then %do;
  %LET CPRPTNM = IN&Type.HR01;
  TITLE1 Hourly &desc Indicator;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    detail
    ,&IndVar,
    ,&TargetVar,
    ,TYPE = JOIN
    ,XVAR = hour
    ,BY = parent node
    ,WHERE = (&IndVar ne .I and &TargetBas eq 'SLI')
    ,REDLVL = admin
    ,BEGIN = latest
    ,END = latest
    ,LTCUTOFF = &slmcutoff
    ,HAXIS = order = 0 to 23 by 1 minor = none
    ,STMTOPT = cframe = &color
    ,PERIOD = hour
    ,VZERO = no
    ,UNIFORM = no
    ,FORMATS = (&IndVar = &IndFmt
                &TargetVar = &IndFmt)
    ,LABELS = (&IndVar = "Indicator"
               &TargetVar = "Target"
               DATETIME = "DATE")
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Hourly
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );

 /*----------------------------------------------------------------------------
  | Report name: INAVHR02 or INRTHR02 or INTHHR02 or INCMHR02
  | Description: Hourly Mean Indicator Plot
  | This is a duplicate of the previous report, without a target value.
  | The target value is not plotted unless it is based on the indicator.
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = IN&Type.HR02;
  TITLE1 Hourly &desc Indicator;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    detail
    ,&IndVar,
    ,TYPE = JOIN
    ,XVAR = hour
    ,BY = parent node
    ,WHERE = (&IndVar ne .I and &TargetBas ne 'SLI')
    ,REDLVL = admin
    ,BEGIN = latest
    ,END = latest
    ,LTCUTOFF = &slmcutoff
    ,HAXIS = order = 0 to 23 by 1 minor = none
    ,STMTOPT = cframe = &color
    ,PERIOD = hour
    ,VZERO = no
    ,UNIFORM = no
    ,FORMATS = (&IndVar = &IndFmt)
    ,LABELS = (&IndVar = "Indicator"
               DATETIME = "DATE")
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Hourly
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );

 /*----------------------------------------------------------------------------
  | Report name: INAVHR03 or INRTHR03 or INTHHR03 or INCMHR03
  | Description: Hourly Indicator Hi - Low Plot
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = IN&Type.HR03;
  TITLE1 Hourly &desc Indicator;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  TITLE4 Minimum, Mean and Maximum;
  %CPPLOT1(
    detail
    ,&IndVar,
    ,TYPE = hilo
    ,XVAR = hour
    ,BY = parent node
    ,WHERE = &IndVar ne .I
    ,REDLVL = admin
    ,BEGIN = latest
    ,END = latest
    ,LTCUTOFF = &slmcutoff
    ,HAXIS = order = 0 to 23 by 1 minor = none
    ,STMTOPT = cframe = &color
    ,PERIOD = hour
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,VZERO = no
    ,UNIFORM = no
    ,FORMATS = (&Indvar = &IndFmt)
    ,LABELS = (&IndVar = "Indicator"
               HOUR = "Hour")
    ,OUTDESC = Hourly
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
  %end; /* Verify admin.detail exists */
 /*----------------------------------------------------------------------------
  | Report name: INAVDY01 or INRTDY01 or INTHDY01 or INCMDY01
  | Description: Daily Mean Indicator Plot
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.day))ne 0) %then %do;
  %LET CPRPTNM = IN&Type.DY01;
  TITLE1 Daily &desc Indicator;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    day
    ,&IndVar,
    ,&TargetVar,
    ,TYPE = JOIN
    ,BY = parent node
    ,WHERE = (&IndVar ne .I and &TargetBas eq 'SLI')
    ,REDLVL = admin
    ,BEGIN = latest-30
    ,END = latest-&offset
    ,STMTOPT = cframe = &color
    ,PERIOD = asis
    ,VZERO = no
    ,UNIFORM = no
    ,FORMATS = (&IndVar = &IndFmt
                &TargetVar = &IndFmt)
    ,LABELS = (&IndVar = "Indicator"
               &TargetVar = "Target"
               DATETIME = "DATE")
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Daily
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );

 /*----------------------------------------------------------------------------
  | Report name: INAVDY02 or INRTDY02 or INTHDY02 or INCMDY02
  | Description: Daily Mean Indicator Plot
  | This is a duplicate of the previous report, without a target value.
  | The target value is not plotted unless it is based on the indicator.
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = IN&Type.DY02;
  TITLE1 Daily &desc Indicator;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    day
    ,&IndVar,
    ,TYPE = JOIN
    ,BY = parent node
    ,WHERE = (&IndVar ne .I and &TargetBas ne 'SLI')
    ,REDLVL = admin
    ,BEGIN = latest-30
    ,END = latest-&offset
    ,STMTOPT = cframe = &color
    ,PERIOD = asis
    ,VZERO = no
    ,UNIFORM = no
    ,FORMATS = (&IndVar = &IndFmt)
    ,LABELS = (&IndVar = "Indicator"
               DATETIME = "DATE")
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Daily
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
  %end; /* Verify admin.day exists */

 /*----------------------------------------------------------------------------
  | Report name: INAVMN01 or INRTMN01 or INTHMN01 or INCMMN01
  | Description: Monthly Mean Indicator Plot
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.month))ne 0) %then %do;
  %LET CPRPTNM = IN&Type.MN01;
  TITLE1 Monthly &desc Indicator;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    month
    ,&IndVar,
    ,&TargetVar,
    ,TYPE = JOIN
    ,BY = parent node
    ,WHERE = (&IndVar ne .I and &TargetBas eq 'SLI')
    ,REDLVL = admin
    ,BEGIN = earliest
    ,END = latest
    ,HAXIS = minor = none
    ,STMTOPT = cframe = &color
    ,PERIOD = month
    ,VZERO = no
    ,UNIFORM = no
    ,FORMATS = (&IndVar = &IndFmt
                &TargetVar = &IndFmt)
    ,LABELS = (&IndVar = "Indicator"
               &TargetVar = "Target"
               DATETIME = "DATE")
    ,PALETTE = PGMLIB.PALETTE.CARNIVLS
    ,OUTDESC = Monthly
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );

 /*----------------------------------------------------------------------------
  | Report name: INAVMN02 or INRTMN02 or INTHMN02 or INCMMN02
  | Description: Monthly Mean Indicator Plot
  | This is a duplicate of the previous report, without a target value.
  | The target value is not plotted unless it is based on the indicator.
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = IN&Type.MN02;
  TITLE1 Monthly &desc Indicator;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    month
    ,&IndVar,
    ,TYPE = JOIN
    ,BY = parent node
    ,WHERE = (&IndVar ne .I and &TargetBas ne 'SLI')
    ,REDLVL = admin
    ,BEGIN = earliest
    ,END = latest
    ,HAXIS = minor = none
    ,STMTOPT = cframe = &color
    ,PERIOD = month
    ,VZERO = no
    ,UNIFORM = no
    ,FORMATS = (&IndVar = &IndFmt)
    ,LABELS = (&IndVar = "Indicator"
               DATETIME = "DATE")
    ,PALETTE = PGMLIB.PALETTE.CARNIVLS
    ,OUTDESC = Monthly
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );

 /*----------------------------------------------------------------------------
  | Report name: INAVMN03 or INRTMN03 or INTHMN03 or INCMMN03
  | Description: Monthly Mean Indicator Chart
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = IN&Type.MN03;
  TITLE1 Monthly &desc Indicator;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPCHART(
    month
    ,date,
    ,&IndVar,
    ,TYPE = VBAR3D
    ,BY = parent node
    ,WHERE = &IndVar ne .I
    ,YVAL = 24
    ,REDLVL = admin
    ,BEGIN = earliest
    ,END = latest
    ,STMTOPT = cframe = &color
    ,PATTRNID = subgroup
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,FORMATS = (&Indvar = &IndFmt
                DATE = date5.  )
    ,LABELS = (&IndVar = "Mean"
               DATE = "Date")
    ,OUTDESC = Monthly
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
  %end; /* Verify admin.month exists */

  %if &Objective = availability or
     &Objective = composite %then %do;

 /*----------------------------------------------------------------------------
  | Run %CPIDTOPN to determine the Bottom 10 nodes for latest day
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.detail))ne 0) %then %do;
  %let BEGIN = latest;
  %let END = latest;

  %CPIDTOPN(
   INLIB = admin
  ,INMEM = detail
  ,BEGIN = &begin
  ,END = &end
  ,MACNAMES = BotAvail
  ,WHERE = &IndVar ne .I
  ,TOPNVARS = &IndVar
  ,TOPNCLAS = node
  ,TOPNSTAT = mean
  ,TOPN = &worst);

 /*----------------------------------------------------------------------------
  | Report name: INAVWT01 or INRTWT01 or INTHWT01 or INCMWT01
  | Description: Day's Worst Mean Indicator Spectrum
  *--------------------------------------------------------------------------*/
  %if &Objective = composite %then %do;
  %LET CPRPTNM = IN&Type.WT01;
  TITLE1 Days Worst &desc Indicator;
  TITLE2 h = 1.5 " #byval(date) ";
  TITLE3 h = 1.5 Spectrum;
  %CPSPEC(
    detail
    ,&IndVar,
    ,CL_NAM = node
    ,REDLVL = admin
    ,BEGIN = &begin
    ,END = &end
    ,LTCUTOFF = &slmcutoff
    ,STMTOPT = cframe = &color
    ,BY = date
    ,PERIOD = 24hour
    ,COLORLST = &colorlst
    ,CTEXT = black
    ,DATAVALS = &dvalues
    ,FORMATS = (&Indvar = &IndFmt)
    ,LABELS = (&IndVar = "Mean"
               DATE = "Date"
               NODE = "Node Name")
    ,WHERE = &BotAvail and &IndVar ne .I
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Worst
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );

    %end; /* Verify admin.detail exists */
    %end;   /* End Objective = composite */

 /*----------------------------------------------------------------------------
  | Report name: INAVWT02 or INRTWT02 or INTHWT02 or INCMWT02
  | Description: Day's Worst Mean Indicator Chart
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.day))ne 0) %then %do;
  %let BEGIN = latest-&offset;
  %let END = latest-&offset;

  %CPIDTOPN(
   INLIB = admin
  ,INMEM = day
  ,BEGIN = &begin
  ,END = &end
  ,MACNAMES = BotAvail
  ,WHERE = &IndVar ne .I
  ,TOPNVARS = &IndVar
  ,TOPNCLAS = node
  ,TOPNSTAT = mean
  ,TOPN = &worst);

  %LET CPRPTNM = IN&Type.WT02;
  TITLE1 Days Worst &desc Indicator;
  TITLE2 h = 1.5 " #byval(date) ";
  TITLE3 h = 1.5 Chart;
  %CPCHART(
    day
    ,node,
    ,&IndVar,
    ,REDLVL = admin
    ,BEGIN = &begin
    ,END = &end
    ,STMTOPT = cframe = &color
    ,BY = date
    ,ORDER = Ascending
    ,TOPN = 10
    ,TYPE = hbar3d
    ,PATTRNID = group
    ,ZERO = no
    ,FORMATS = (&Indvar = &IndFmt)
    ,LABELS = (&IndVar = "Mean"
               DATE = "Date"
               NODE = "Node Name")
    ,WHERE = &BotAvail and &IndVar ne .I
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Worst
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
    %end; /* Verify admin.day exists */

 /*----------------------------------------------------------------------------
  | Run %CPIDTOPN to determine the Bottom 10 nodes for latest month
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.month))ne 0) %then %do;
  %let BEGIN = latest;
  %let END = latest;

  %CPIDTOPN(
   INLIB = admin
  ,INMEM = month
  ,BEGIN = &begin
  ,END = &end
  ,MACNAMES = BotAvail
  ,WHERE = &IndVar ne .I
  ,TOPNVARS = &IndVar
  ,TOPNCLAS = node
  ,TOPNSTAT = mean
  ,TOPN = &worst);

 /*----------------------------------------------------------------------------
  | Report name: INAVWT04 or INRTWT04 or INTHWT04 or INCMWT04
  | Description: Months Worst Mean Indicator Chart
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = IN&Type.WT04;
  TITLE1 Months Worst &desc Indicator;
  %CPCHART(
    month
    ,node,
    ,&IndVar,
    ,REDLVL = admin
    ,BEGIN = &begin
    ,END = &end
    ,STMTOPT = cframe = &color
    ,BY = date
    ,ORDER = Ascending
    ,TOPN = 10
    ,TYPE = hbar3d
    ,PATTRNID = group
    ,ZERO = no
    ,FORMATS = (&IndVar = &IndFmt)
    ,LABELS = (&IndVar = "Mean"
               DATE = "Date"
               NODE = "Node Name")
    ,WHERE = &BotAvail and &IndVar ne .I
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Worst
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.month exists */
 /*----------------------------------------------------------------------------
  | Run %CPIDTOPN to determine the Top 10 nodes for latest day
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.detail))ne 0) %then %do;
  %let BEGIN = latest;
  %let END = latest;

  %CPIDTOPN(
   INLIB = admin
  ,INMEM = detail
  ,BEGIN = &begin
  ,END = &end
  ,LTCUTOFF = &slmcutoff
  ,MACNAMES = TopAvail
  ,WHERE = &IndVar ne .I
  ,TOPNVARS = &IndVar
  ,TOPNCLAS = node
  ,TOPNSTAT = mean
  ,TOPN = &best);

 /*----------------------------------------------------------------------------
  | Report name: INAVBT01 or INRTBT01 or INTHBT01 or INCMBT01
  | Description: Days Best Mean Indicator Spectrum
  *--------------------------------------------------------------------------*/
  %if &Objective = composite %then %do;

  %LET CPRPTNM = IN&Type.BT01;
  TITLE1 Days Best &desc Indicator;
  TITLE2 h = 1.5 " #byval(date) ";
  TITLE3 h = 1.5 Spectrum;
  %CPSPEC(
    detail
    ,&IndVar,
    ,CL_NAM = node
    ,REDLVL = admin
    ,BEGIN = &begin
    ,END = &end
    ,LTCUTOFF = &slmcutoff
    ,STMTOPT = cframe = &color
    ,BY = date
    ,PERIOD = 24hour
    ,COLORLST = &colorlst
    ,CTEXT = black
    ,DATAVALS = &dvalues
    ,FORMATS = (&Indvar = &IndFmt)
    ,LABELS = (&IndVar = "Mean"
               DATE = "Date"
               NODE = "Node Name")
    ,WHERE = &TopAvail and &IndVar ne .I
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Best
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );

   %end;   /* End Objective = composite */
   %end; /* Verify admin.detail exists */

 /*----------------------------------------------------------------------------
  | Report name: INAVBT02 or INRTBT02 or INTHBT02 or INCMBT02
  | Description: Days Best Mean Indicator Chart
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.day))ne 0) %then %do;
  %let BEGIN = latest - &offset;
  %let END = latest - &offset;

  %CPIDTOPN(
   INLIB = admin
  ,INMEM = day
  ,BEGIN = &begin
  ,END = &end
  ,MACNAMES = TopAvail
  ,WHERE = &IndVar ne .I
  ,TOPNVARS = &IndVar
  ,TOPNCLAS = node
  ,TOPNSTAT = mean
  ,TOPN = &best);

  %LET CPRPTNM = IN&Type.BT02;
  TITLE1 Days Best &desc Indicator;
  TITLE2 h = 1.5 " #byval(date) ";
  TITLE3 h = 1.5 Chart;
  %CPCHART(
    day
    ,node,
    ,&IndVar,
    ,REDLVL = admin
    ,BEGIN = &begin
    ,END = &end
    ,BY = date
    ,STMTOPT = cframe = &color
    ,ORDER = Descending
    ,TOPN = 10
    ,TYPE = hbar3d
    ,PATTRNID = group
    ,ZERO = no
    ,FORMATS = (&Indvar = &IndFmt)
    ,LABELS = (&IndVar = "Mean"
               DATE = "Date"
               NODE = "Node Name")
    ,WHERE = &TopAvail and &IndVar ne .I
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Best
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.day exists */

 /*----------------------------------------------------------------------------
  | Run %CPIDTOPN to determine the Bottom 10 nodes for latest month
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.month))ne 0) %then %do;
  %let BEGIN = latest;
  %let END = latest;

  %CPIDTOPN(
   INLIB = admin
  ,INMEM = month
  ,BEGIN = &begin
  ,END = &end
  ,MACNAMES = TopAvail
  ,WHERE = &IndVar ne .I
  ,TOPNVARS = &IndVar
  ,TOPNCLAS = node
  ,TOPNSTAT = mean
  ,TOPN = &best);

 /*----------------------------------------------------------------------------
  | Report name: INAVBT04 or INRTBT04 or INTHBT04 or INCMBT04
  | Description: Months Best Mean Indicator Chart
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = IN&Type.BT04;
  TITLE1 Months Best &desc Indicator;
  %CPCHART(
    month
    ,node,
    ,&IndVar,
    ,REDLVL = admin
    ,BEGIN = &begin
    ,END = &end
    ,STMTOPT = cframe = &color
    ,BY = date
    ,ORDER = Descending
    ,TOPN = 10
    ,TYPE = hbar3d
    ,PATTRNID = group
    ,ZERO = no
    ,FORMATS = (&Indvar = &IndFmt)
    ,LABELS = (&IndVar = "Mean"
               DATE = "Date"
               NODE = "Node Name")
    ,WHERE = &TopAvail and &IndVar ne .I
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Best
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.month exists */
   %end; /* End Objective = availability or composite */

 /*----------------------------------------------------------------------------
  | Report name: INAVTR01 or INRTTR01 or INTHTR01 or INCMTR01
  | Description: Mean Indicator Regression Plot
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.day))ne 0) %then %do;
  %cpsethax(
  data = admin.day,
  dsvar = datetime,
  macvar = regaxis,
  extend = 1.5
  );

  %LET CPRPTNM = IN&Type.TR01;
  TITLE1 &desc Indicator Trend;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    day
    ,&IndVar,
    ,TYPE = RQCLM95
    ,BY = parent node
    ,WHERE = &IndVar ne .I
    ,REDLVL = admin
    ,BEGIN = earliest
    ,END = latest - &offset
    ,PERIOD = date
    ,VZERO = no
    ,vref = 0 &regaxis
    ,UNIFORM = no
    ,FORMATS = (&Indvar = &IndFmt)
    ,LABELS = (&IndVar = "Indicator"
               DATETIME = "DATE")
    ,PALETTE = PGMLIB.PALETTE.CARNIVLS
    ,OUTDESC = Trends
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.day exists */

  %exit1:
 %mend RptInd;


 /*----------------------------------------------------------------------------
  | #2: This macro, %RptScore, generates Score reports in a web Gallery.
  | It produces Availability, Response Time and Throughput Score Reports,
  | depending upon the parameter supplied to the macro. Valid calls are:
  |
  |      %RptScore(Objective = availability);
  |      %RptScore(Objective = response);
  |      %RptScore(Objective = throughput);
  |
  | Reports below include Hourly, Daily, Monthly, Worst, Best and Trend
  | Reports. This macro calls the macro %CPWEBINI to initialize the
  | directory before it runs the reports. It calls %CPIDTOPN to determine
  | the Top N and Bottom N nodes for reporting best and worst performers.
  *--------------------------------------------------------------------------*/
  %macro RptScore(Objective = );
  %let Objective = %lowcase(&Objective);
 /*----------------------------------------------------------------------------
  | Check Return code from %CPSLMCON before proceeding.
  *--------------------------------------------------------------------------*/
  %if &slmrc gt 0 %then %do;
      %put ************************************************************;
      %put ERROR: Database not active. Check your log for prior errors;
      %put ERROR: Score &Objective Reports Not Run;
      %put ************************************************************;
      %goto exit1;
  %end;

 /*----------------------------------------------------------------------------
  | Verify that CPSLMCRP exists before proceeding.
  *--------------------------------------------------------------------------*/
  %let SLMDIRCHK = %CPSEP(&CPSLMCRP)slm;
  %if (&CPOPSYS ne MVS) and (%sysfunc(fileexist(&SLMDIRCHK))=0) %then %do;
      %put ************************************************************;
      %put ERROR: &SLMDIRCHK Does not exist. Check your log for previous;
      %put ERROR: errors. ;
      %put ************************************************************;
      %goto exit1;
  %end;

 /*----------------------------------------------------------------------------
  | Set macro variables used by the Score Reports.
  |
  | The Score reports below can be Availability, Response Time or
  | Throughput reports. The Report name (CPRPTNM), titles, labels and
  | variables graphed depend on the parameter provided at macro invocation
  | time.
  |
  | CUSTOMIZE: (Optional)
  | There are a few macro variables defined below that you may choose to
  | modify for your site.
  | 1. Indfmt and Srcfmt: These macro variables are used to format the
  |    indicator and score values. They are hard coded to 12.2 and 8.
  |    respectively. You may change the values to any valid SAS graph
  |    format values or you may use a BEST format, such as BEST12.2
  |    to allow SAS graph to guess at a best format based on the data.
  | 2. best and worst: These macro variables are used to determine the
  |    numbers for the top and bottom performers. If you change the values
  |    be sure to preserve the sign.
  | CUSTOMIZE: (Recommended)
  | 3. colorlst and dvalues: Used by reports on Availability objectives.
  |    These variables are used in conjuction to determine the numeric grouping
  |    and legend of the data in the spectrum reports, called by the %CPSPEC
  |    macro. The default values of 1, 2, 3 and 4 and the colors used below
  |    can be changed to correspond to your composite scoring pattern.
  |
  |    These are the default colors:
  |    CXFAF8ED light beige for missing values
  |    CXCC0066 red
  |    CXFFCC00 yellow
  |    CX669966 green
  |    CX336699 blue
  |
  |    The default values for dvalues and colorlst below will generate
  |    a spectrum report with the following legend:
  |
  |       blue <= 1 ; green <= 2 ; yellow <= 3 ; red <= 4
  |
  |    These default values can be used with a scoring pattern where 1
  |    represents Excellent, 2 represents Good, 3 represents Fair and 4
  |    represents Poor.
  |
  |    Modify these values to match your scoring pattern. You may also add
  |    additional values. Be sure to add an additional color for each additional
  |    value that is added. Note that the extra color in the colorlst is beige,
  |    which is used for missing values.
  | 4. plotAxis and chartAxis: These macro variables are used by plot and chart
  |    macros, %CPPLOT1, %CPPLOT2 and %CPCHART to control the horizontal or the
  |    vertical axis of the reports. If you use a consistent scoring pattern
  |    (recommended) then follow the customization instructions below to modify
  |    the values for &plotAxis and &chartAxis. If you do not usea consistent
  |    scoring pattern then disable the use of &plotAxis and &chartAxis by
  |    removing all occurences of the following strings:
  |
  |       ,VAXIS = &plotAxis
  |       ,AXIS = &chartAxis
  |
  |    In summary, using these parameters in the report invocations below gives
  |    you more control of the axis. Removing the use of these parameters will
  |    produce reports with default axis determined by SAS/Graph.
  |
  | Note that some score report below compare the best and worst performers.
  | These are the Day's Best, Day's Worst, Month's Best and Month's Worst.
  | If you are not using a consistent scoring pattern then you may wish to
  | disable these score reports. You can disable any report by adding an "*"
  | after the percent symbol. For example to disable a %CPCHART report, change
  | the from to %CPCHART to %*CPCHART.
  *--------------------------------------------------------------------------*/
  %if &Objective = availability %then %do;
          %let desc = Availability;
          %let type = AV;
          %let dirname = slmsa;
          %let catname = slmsa;
          %let ScoreVar = ascore;
          %let IndVar = asli;
          %let TargetVar = atarget;
          %let TargetBas = atgtbas;
          %let best = -10;
          %let worst = 10;
          %let dvalues = 1 2 3 4;
          %let plotAxis = order = 1 to 4 by 1 minor = none;
          %let chartAxis = 0 to 4 by 1;
          %let colorlst = CXFAF8ED CX336699 CX669966 CXFFCC00 CXCC0066;
          %let ScrFmt = 8.;
          %let IndFmt = 12.2;
   %end;
   %else %if &Objective = response %then %do;
          %let desc = Response Time;
          %let type = RT;
          %let dirname = slmsr;
          %let catname = slmsr;
          %let ScoreVar = rscore;
          %let IndVar = rsli;
          %let TargetVar = rtarget;
          %let TargetBas = rtgtbas;
          %let best = -10;
          %let worst = 10;
          %let plotAxis = order = 1 to 4 by 1 minor = none;
          %let chartAxis = 0 to 4 by 1;
          %let ScrFmt = 8.;
          %let IndFmt = 12.2;
   %end;
   %else %if &Objective = throughput %then %do;
          %let desc = Throughput;
          %let type = TH;
          %let dirname = slmst;
          %let catname = slmst;
          %let ScoreVar = tscore;
          %let IndVar = tsli;
          %let TargetVar = ttarget;
          %let TargetBas = ttgtbas;
          %let best = -10;
          %let worst = 10;
          %let plotAxis = order = 1 to 4 by 1 minor = none;
          %let chartAxis = 0 to 4 by 1 ;
          %let ScrFmt = 8.;
          %let IndFmt = 12.2;
   %end;
   %else %do;
      %put ***************************************************;
      %put ERROR: Valid parameters are;
      %put Availability, Respose and Throughput  ;
      %put ***************************************************;
      %goto exit1;
   %end;

 /*----------------------------------------------------------------------------
  | %CPWEBINI initializes the directory, folder, or PDS before creating
  | the reports.
  *--------------------------------------------------------------------------*/
  %cpwebini(cat = work.&catname, dir = &cpslmcrp.&dirname,
      WEBSTYLE = &webstyle);

 /*----------------------------------------------------------------------------
  | Report name: SCAVHR01 or SCRTHR01 or SCTHHR01
  | Description: Hourly Score Hi - Low Plot
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.detail))ne 0) %then %do;
  %LET CPRPTNM = SC&Type.HR01;
  TITLE1 Hourly &desc Score;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    detail
    ,&ScoreVar,
    ,TYPE = hilo
    ,XVAR = hour
    ,BY = parent node
    ,WHERE = &ScoreVar gt .Z
    ,REDLVL = admin
    ,BEGIN = latest
    ,END = latest
    ,LTCUTOFF = &slmcutoff
    ,HAXIS = order = 0 to 23 by 1 minor = none
    ,VAXIS = &plotaxis
    ,STMTOPT = cframe = &color
    ,PERIOD = hour
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,VZERO = no
    ,UNIFORM = Yes
    ,FORMATS = (&ScoreVar = &ScrFmt)
    ,LABELS = (&ScoreVar = "Score"
               Hour = "Hour")
    ,OUTDESC = Hourly
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );

 /*----------------------------------------------------------------------------
  | Report name: SCAVHR02 or SCRTHR02 or SCTHHR02
  | Description: Hourly Mean Score vs Indicator Plot
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = SC&Type.HR02;
  TITLE1 Hourly &desc Score vs. Indicator;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT2(
    detail
    ,&ScoreVar,
    ,&IndVar,
    ,BY = parent node
    ,WHERE = &ScoreVar gt .Z
    ,REDLVL = admin
    ,BEGIN = latest
    ,END = latest
    ,LTCUTOFF = &slmcutoff
    ,VAXIS = &plotaxis
    ,STMTOPT = cframe = &color
    ,PERIOD = hour
    ,VZERO = no
    ,VZERO2 = no
    ,UNIFORM = Yes
    ,FORMATS = (&ScoreVar=&ScrFmt
                &IndVar=&IndFmt)
    ,LABELS = (&ScoreVar="Score"
               &IndVar="Indicator")
    ,PALETTE = PGMLIB.PALETTE.CARNIVLS
    ,OUTDESC = Hourly
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
  %end; /* Verify admin.detail exists */
 /*----------------------------------------------------------------------------
  | Report name: SCAVDY01 or SCRTDY01 or SCTHDY01
  | Description: Daily Score Plot
  | The target value is plotted when it is based on the score.
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.day))ne 0) %then %do;
  %LET CPRPTNM = SC&Type.DY01;
  TITLE1 Daily &desc Score;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    day
    ,&ScoreVar,
    ,&TargetVar,
    ,TYPE = SCATTER
    ,BY = parent node
    ,WHERE = (&ScoreVar gt .Z and &TargetBas eq 'SCORE')
    ,REDLVL = admin
    ,BEGIN = latest-30
    ,END = latest-&offset
    ,VAXIS = &plotaxis
    ,STMTOPT = cframe = &color
    ,PERIOD = asis
    ,VZERO = no
    ,UNIFORM = yes
    ,FORMATS = (&ScoreVar = &ScrFmt
                &TargetVar = &ScrFmt)
    ,LABELS = (&ScoreVar = "Score"
               &TargetVar = "Target"
               DATETIME = "DATE")
    ,PALETTE = PGMLIB.PALETTE.CARNIVLS
    ,OUTDESC = Daily
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );

 /*----------------------------------------------------------------------------
  | Report name: SCAVDY02 or SCRTDY02 or SCTHDY02
  | Description: Daily Score Plot
  | This is a duplicate of the previous report, without the target value.
  | The target value is not plotted when it is based on the indicator.
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = SC&Type.DY02;
  TITLE1 Daily &desc Score;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    day
    ,&ScoreVar,
    ,TYPE = SCATTER
    ,BY = parent node
    ,WHERE = (&ScoreVar gt .Z and &TargetBas ne 'SCORE')
    ,REDLVL = admin
    ,BEGIN = latest-30
    ,END = latest-&offset
    ,VAXIS = &plotaxis
    ,STMTOPT = cframe = &color
    ,PERIOD = asis
    ,VZERO = no
    ,UNIFORM = yes
    ,FORMATS = (&ScoreVar = &ScrFmt)
    ,LABELS = (&ScoreVar = "Score"
               DATETIME = "DATE")
    ,PALETTE = PGMLIB.PALETTE.CARNIVLS
    ,OUTDESC = Daily
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.day exists */

 /*----------------------------------------------------------------------------
  | Report name: SCAVMN01 or SCRTMN01 or SCTHMN01
  | Description: Monthly Score Chart
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.month))ne 0) %then %do;
  %LET CPRPTNM = SC&Type.MN01;
  TITLE1 Monthly &desc Score;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPCHART(
    month
    ,date,
    ,&scoreVar,
    ,TYPE = VBAR3D
    ,BY = parent node
    ,WHERE = &scoreVar gt .Z
    ,YVAL = 24
    ,REDLVL = admin
    ,BEGIN = earliest
    ,END = latest
    ,AXIS = &chartAxis
    ,STMTOPT = cframe = &color
    ,PATTRNID = subgroup
    ,PALETTE = PGMLIB.PALETTE.CARNIVLS
    ,FORMATS = (&ScoreVar = &ScrFmt
                DATE = date5. )
    ,LABELS = (&ScoreVar = "Mean"
               DATE = "Date")
    ,OUTDESC = Monthly
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.month exists */

 /*----------------------------------------------------------------------------
  | Run %CPIDTOPN to determine the Bottom 10 nodes for latest day
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.detail))ne 0) %then %do;
  %let BEGIN = latest;
  %let END = latest;

  %CPIDTOPN(
   INLIB = admin
  ,INMEM = detail
  ,BEGIN = &begin
  ,END = &end
  ,LTCUTOFF = &slmcutoff
  ,MACNAMES = BotAvail
  ,WHERE = &ScoreVar gt .Z
  ,TOPNVARS = &ScoreVar
  ,TOPNCLAS = node
  ,TOPNSTAT = mean
  ,TOPN = &worst);

 %if &Objective = availability %then %do;
 /*----------------------------------------------------------------------------
  | Report name: SCAVWT01 or SCRTWT01 or SCTHWT01
  | Description: Day's Worst Mean Score Spectrum
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = SC&Type.WT01;
  TITLE1 Days Worst &desc Score;
  TITLE2 h = 1.5 " #byval(date) ";
  TITLE3 h = 1.5 Spectrum;
  %CPSPEC(
    detail
    ,&ScoreVar,
    ,CL_NAM = node
    ,REDLVL = admin
    ,BEGIN = &begin
    ,END = &end
    ,LTCUTOFF = &slmcutoff
    ,STMTOPT = cframe = &color
    ,BY = date
    ,WHERE = &BotAvail and &ScoreVar gt .Z
    ,PERIOD = 24hour
    ,COLORLST = &colorlst
    ,CTEXT = black
    ,DATAVALS = &dvalues
    ,FORMATS = (&ScoreVar = &ScrFmt)
    ,LABELS = (&ScoreVar = "Score"
               DATE = "Date"
               NODE = "Node Name")
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Worst
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
 %end;   /* End Objective = availability */
 %end; /* Verify admin.detail exists */

 /*----------------------------------------------------------------------------
  | Report name: SCAVWT02 or SCRTWT02 or SCTHWT02
  | Description: Day's Worst Mean Score Chart
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.day))ne 0) %then %do;
  %let BEGIN = latest-&offset;
  %let END = latest-&offset;

  %CPIDTOPN(
   INLIB = admin
  ,INMEM = day
  ,BEGIN = &begin
  ,END = &end
  ,MACNAMES = BotAvail
  ,WHERE = &ScoreVar gt .Z
  ,TOPNVARS = &ScoreVar
  ,TOPNCLAS = node
  ,TOPNSTAT = mean
  ,TOPN = &worst);

  %LET CPRPTNM = SC&Type.WT02;
  TITLE1 Days Worst &desc Score;
  TITLE2 h = 1.5 " #byval(date) ";
  TITLE3 h = 1.5 Chart;
  %CPCHART(
    day
    ,node,
    ,&ScoreVar,
    ,REDLVL = admin
    ,BEGIN = &begin
    ,END = &end
    ,AXIS = &chartAxis
    ,STMTOPT = cframe = &color
    ,BY = date
    ,WHERE = &BotAvail and &ScoreVar gt .Z
    ,ORDER = descending
    ,TOPN = 10
    ,TYPE = hbar3d
    ,PATTRNID = group
    ,ZERO = no
    ,FORMATS = (&ScoreVar = &ScrFmt)
    ,LABELS = (&ScoreVar = "Score"
               DATE = "Date"
               NODE = "Node Name")
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Worst
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.day exists */

 /*----------------------------------------------------------------------------
  | Run %CPIDTOPN to determine the Bottom 10 nodes for latest month
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.month))ne 0) %then %do;
  %let BEGIN = latest;
  %let END = latest;

  %CPIDTOPN(
   INLIB = admin
  ,INMEM = month
  ,BEGIN = &begin
  ,END = &end
  ,MACNAMES = BotAvail
  ,WHERE = &ScoreVar gt .Z
  ,TOPNVARS = &ScoreVar
  ,TOPNCLAS = node
  ,TOPNSTAT = mean
  ,TOPN = &worst);

 /*----------------------------------------------------------------------------
  | Report name: SCAVWT04 or SCRTWT04 or SCTHWT04
  | Description: Months Worst Mean Score Chart
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = SC&Type.WT04;
  TITLE1 Months Worst &desc Score;
  %CPCHART(
    month
    ,node,
    ,&ScoreVar,
    ,REDLVL = admin
    ,BEGIN = &begin
    ,END = &end
    ,AXIS = &chartAxis
    ,STMTOPT = cframe = &color
    ,BY = date
    ,ORDER = Descending
    ,TOPN = 10
    ,TYPE = hbar3d
    ,PATTRNID = group
    ,ZERO = no
    ,FORMATS = (&ScoreVar = &ScrFmt)
    ,LABELS = (&ScoreVar = "Score"
               DATE = "Date"
               NODE = "Node Name")
    ,WHERE = &BotAvail and &ScoreVar gt .Z
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Worst
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.month exists */
 /*----------------------------------------------------------------------------
  | Run %CPIDTOPN to determine the Top 10 nodes for latest day
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.detail))ne 0) %then %do;
  %let BEGIN = latest;
  %let END = latest;

  %CPIDTOPN(
   INLIB = admin
  ,INMEM = detail
  ,BEGIN = &begin
  ,END = &end
  ,LTCUTOFF = &slmcutoff
  ,MACNAMES = TopAvail
  ,WHERE = &ScoreVar gt .Z
  ,TOPNVARS = &ScoreVar
  ,TOPNCLAS = node
  ,TOPNSTAT = mean
  ,TOPN = &best);

 %if &Objective = availability %then %do;
 /*----------------------------------------------------------------------------
  | Report name: SCAVBT01 or SCRTBT01 or SCTHBT01
  | Description: Day's Best Mean Score Spectrum
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = SC&Type.BT01;
  TITLE1 Days Best &desc Score;
  TITLE2 h = 1.5 " #byval(date) ";
  TITLE3 h = 1.5 Spectrum;
  %CPSPEC(
    detail
    ,&ScoreVar,
    ,CL_NAM = node
    ,REDLVL = admin
    ,BEGIN = latest
    ,END = latest
    ,LTCUTOFF = &slmcutoff
    ,STMTOPT = cframe = &color
    ,BY = date
    ,PERIOD = 24hour
    ,COLORLST = &colorlst
    ,CTEXT = black
    ,DATAVALS = &dvalues
    ,FORMATS = (&ScoreVar = &ScrFmt)
    ,LABELS = (&ScoreVar = "Score"
               DATE = "Date"
               NODE = "Node Name")
    ,WHERE = &BotAvail and &ScoreVar gt .Z
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Best
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
 %end; /* End Objective = availability */
 %end; /* Verify admin.detail exists */

 /*----------------------------------------------------------------------------
  | Report name: SCAVBT02 or SCRTBT02 or SCTHBT02
  | Description: Day's Best Mean Score Chart
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.day))ne 0) %then %do;
  %let BEGIN =  latest-&offset;
  %let END =  latest-&offset;

  %CPIDTOPN(
   INLIB = admin
  ,INMEM = day
  ,BEGIN = &begin
  ,END = &end
  ,MACNAMES = TopAvail
  ,WHERE = &ScoreVar gt .Z
  ,TOPNVARS = &ScoreVar
  ,TOPNCLAS = node
  ,TOPNSTAT = mean
  ,TOPN = &best);

  %LET CPRPTNM = SC&Type.BT02;
  TITLE1 Days Best &desc Score;
  TITLE2 h = 1.5 " #byval(date) ";
  TITLE3 h = 1.5 Chart;
  %CPCHART(
    day
    ,node,
    ,&ScoreVar,
    ,REDLVL = admin
    ,BEGIN = &begin
    ,END = &end
    ,AXIS = &chartAxis
    ,BY = date
    ,STMTOPT = cframe = &color
    ,ORDER = Ascending
    ,TOPN = 10
    ,TYPE = hbar3d
    ,PATTRNID = group
    ,ZERO = no
    ,FORMATS = (&ScoreVar = &ScrFmt)
    ,LABELS = (&ScoreVar = "Score"
               DATE = "Date"
               NODE = "Node Name")
    ,WHERE = &BotAvail and &ScoreVar gt .Z
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Best
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.day exists */

 /*----------------------------------------------------------------------------
  | Run %CPIDTOPN to determine the Top 10 nodes for the latest month
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.month))ne 0) %then %do;
  %let BEGIN = latest;
  %let END = latest;

  %CPIDTOPN(
   INLIB = admin
  ,INMEM = month
  ,BEGIN = &begin
  ,END = &end
  ,MACNAMES = TopAvail
  ,WHERE = &ScoreVar gt .Z
  ,TOPNVARS = &ScoreVar
  ,TOPNCLAS = node
  ,TOPNSTAT = mean
  ,TOPN = &best);

 /*----------------------------------------------------------------------------
  | Report name: SCAVBT04 or SCRTBT04 or SCTHBT04
  | Description: Month's Best Mean Score Chart
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = SC&Type.BT04;
  TITLE1 Months Best &desc Score;
  %CPCHART(
    month
    ,node,
    ,&ScoreVar,
    ,REDLVL = admin
    ,BEGIN = &begin
    ,END = &end
    ,AXIS = &chartAxis
    ,STMTOPT = cframe = &color
    ,BY = date
    ,ORDER = Ascending
    ,TOPN = 10
    ,TYPE = hbar3d
    ,PATTRNID = group
    ,ZERO = no
    ,FORMATS = (&ScoreVar = &ScrFmt)
    ,LABELS = (&ScoreVar = "Score"
               DATE = "Date"
               NODE = "Node Name")
    ,WHERE = &TopAvail and &ScoreVar gt .Z
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Best
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.month exists */

 /*----------------------------------------------------------------------------
  | Report name: SCAVTR01 or SCRTTR01 or SCTHTR01
  | Description: Mean Score Regression Plot
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.day))ne 0) %then %do;
  %cpsethax(
  data = admin.day,
  dsvar = datetime,
  macvar = regaxis,
  extend = 1.5
  );

  %LET CPRPTNM = SC&Type.TR01;
  TITLE1 &desc Score Trend;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    day
    ,&ScoreVar,
    ,REDLVL = admin
    ,BEGIN = earliest
    ,END =  latest-&offset
    ,VAXIS = &plotAxis
    ,TYPE = RQCLM95
    ,STMTOPT = cframe = &color
    ,BY = parent node
    ,WHERE = &ScoreVar gt .Z
    ,PERIOD = date
    ,VZERO = no
    ,vref = 0 &regaxis
    ,UNIFORM = YES
    ,FORMATS = (&ScoreVar = &ScrFmt)
    ,LABELS = (&ScoreVar = "Score"
               DATETIME = "DATE")
    ,PALETTE = PGMLIB.PALETTE.CARNIVLS
    ,OUTDESC = Trends
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
  %end; /* Verify admin.day exists */
  %exit1:
 %mend RptScore;

 /*----------------------------------------------------------------------------
  | #3: This macro, %RptARTScore, generates Score reports in a web Gallery. It
  | produces Availability, Response Time and Throughput Score on one graph.
  | It does not take a parameter. The only valid call is:
  |
  |      %RptARTScore;
  |
  | Reports below include Hourly, Daily, and Monthly Reports. This macro
  | calls the macro %CPWEBINI to initialize the directory before it runs
  | the reports.
  |
  | If you are not using a consistent scoring pattern then do not run these
  | reports.
  *--------------------------------------------------------------------------*/
  %macro RptARTScore;

 /*----------------------------------------------------------------------------
  | Check Return code from %CPSLMCON before proceeding.
  *--------------------------------------------------------------------------*/
  %if &slmrc gt 0 %then %do;
      %put ************************************************************;
      %put ERROR: Database not active. Check your log for prior errors;
      %put ERROR: Score ART Reports Not Run;
      %put ************************************************************;
      %goto exit1;
  %end;

 /*----------------------------------------------------------------------------
  | Verify that the CPSLMCRP exists before proceeding.
  *--------------------------------------------------------------------------*/
  %let SLMDIRCHK = %CPSEP(&CPSLMCRP)slm;
  %if (&CPOPSYS ne MVS) and (%sysfunc(fileexist(&SLMDIRCHK))=0) %then %do;
      %put ************************************************************;
      %put ERROR: &SLMDIRCHK Does not exist. Check your log for previous;
      %put ERROR: errors. ;
      %put ************************************************************;
      %goto exit1;
  %end;

 /*----------------------------------------------------------------------------
  | Set macro variables used by the ART Score Reports.
  |
  | CUSTOMIZE: (Recommended)
  | There are a few macro variables defined below that you may choose to
  | modify for your site.
  | 1. colorlst and dvalues: Used by all the spectrum reports in this macro.
  |    These variables are used in conjuction to determine the numeric grouping
  |    and legend of the data in the spectrum reports, called by the %CPSPEC
  |    macro. The default values of 1, 2, 3 and 4 and the colors used below
  |    can be changed to correspond to your composite scoring pattern.
  |
  |    These are the default colors:
  |    CXFAF8ED light beige for missing values
  |    CXCC0066 red
  |    CXFFCC00 yellow
  |    CX669966 green
  |    CX336699 blue
  |
  |    The default values for dvalues and colorlst below will generate
  |    a spectrum report with the following legend:
  |
  |       blue <= 1 ; green <= 2 ; yellow <= 3 ; red <= 4
  |
  |    These default values can be used with a scoring pattern where 1
  |    represents Excellent, 2 represents Good, 3 represents Fair and 4
  |    represents Poor.
  |
  |    Modify these values to match your scoring pattern. You may also add
  |    additional values. Be sure to add an additional color for each additional
  |    value that is added. Note that the extra color in the colorlst is beige,
  |    which is used for missing values.
  *--------------------------------------------------------------------------*/
  %let dirname = slmsn;
  %let catname = slmsn;
  %let dvalues = 1 2 3 4;
  %let colorlst = CXFAF8ED CX336699 CX669966 CXFFFF99 CXCC0066;

 /*----------------------------------------------------------------------------
  | %CPWEBINI initializes the directory, folder, or PDS before creating
  | the reports.
  *--------------------------------------------------------------------------*/
  %cpwebini(cat = work.&catname, dir = &cpslmcrp.&dirname,
      WEBSTYLE = &webstyle);

 /*----------------------------------------------------------------------------
  | Report name: SCARTHR1
  | Description: Hourly Availability, Response Time and Throughput Scores
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.detail))ne 0) %then %do;
  %LET CPRPTNM = SCARTHR1;
  TITLE1 Hourly Availability, Response and Throughput Scores;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPSPEC(
    detail
    ,ASCORE,
    ,RSCORE,
    ,TSCORE,
    ,BY = parent node
    ,WHERE = (ascore gt .Z or rscore gt .Z or tscore gt .Z)
    ,REDLVL = admin
    ,BEGIN = latest
    ,END = latest
    ,LTCUTOFF = &slmcutoff
    ,STMTOPT = cframe = &color
    ,PERIOD = 24hour
    ,STAT = mean
    ,COLORLST = &colorlst
    ,CTEXT = black
    ,DATAVALS = &dvalues
    ,LABELS = (ASCORE = "Availability"
               TSCORE = "Throughput"
               RSCORE = "Response Time")
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Hourly
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.detail exists */
 /*----------------------------------------------------------------------------
  | Report name: SCARTDY1
  | Description: Daily Availability, Response Time and Throughput Scores
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.day))ne 0) %then %do;
  %LET CPRPTNM = SCARTDY1;
  TITLE1 Daily Availability, Response and Throughput Scores;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPSPEC(
    day
    ,ASCORE,
    ,RSCORE,
    ,TSCORE,
    ,BY = parent node
    ,WHERE = (ascore gt .Z or rscore gt .Z or tscore gt .Z)
    ,REDLVL = admin
    ,BEGIN = latest-31
    ,END =  latest-&offset
    ,STMTOPT = cframe = &color
    ,PERIOD = date
    ,STAT = mean
    ,COLORLST = &colorlst
    ,CTEXT = black
    ,DATAVALS = &dvalues
    ,LABELS = (ASCORE = "Availability"
               TSCORE = "Throughput"
               RSCORE = "Response Time")
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Daily
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.day exists */

 /*----------------------------------------------------------------------------
  | Report name: SCARTMN1
  | Description: Monthly Availability, Response Time and Throughput
  |              Scores
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.month))ne 0) %then %do;
  %LET CPRPTNM = SCARTMN1;
  TITLE1 Monthly Availability, Response and Throughput Scores;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPSPEC(
    month
    ,ASCORE,
    ,RSCORE,
    ,TSCORE,
    ,BY = parent node
    ,WHERE = (ascore gt .Z or rscore gt .Z or tscore gt .Z)
    ,REDLVL = admin
    ,BEGIN = earliest
    ,END = latest
    ,STMTOPT = cframe = &color
    ,PERIOD = date
    ,STAT = mean
    ,COLORLST = &colorlst
    ,CTEXT = black
    ,DATAVALS = &dvalues
    ,LABELS = (ASCORE = "Availability"
               TSCORE = "Throughput"
               RSCORE = "Response Time"
               Datetime = "Datetime")
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Monthly
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
  %end; /* Verify admin.month exists */
  %exit1:
 %mend RptARTScore;

 /*----------------------------------------------------------------------------
  | #4: This macro, %RptTarget, generates Targets and Outage reports in a web
  | Gallery. It produces Availability, Response Time and Throughput Target and
  | Outage Reports, depending upon the parameter supplied to the macro. Valid
  | calls are:
  |
  |      %RptTarget(Objective = availability);
  |      %RptTarget(Objective = response);
  |      %RptTarget(Objective = throughput);
  |
  | Reports below include Hourly, Daily, Monthly, Worst, Best and Trend
  | Reports. This macro calls the macro %CPWEBINI to initialize the
  | directory before it runs the reports. It calls %CPIDTOPN to determine
  | the Top N and Bottom N nodes for reporting best and worst performers.
  *--------------------------------------------------------------------------*/
  %macro RptTarget(Objective = );
  %let Objective = %lowcase(&Objective);

  /*----------------------------------------------------------------------------
  | Check Return code from %CPSLMCON before proceeding.
  *--------------------------------------------------------------------------*/
  %if &slmrc gt 0 %then %do;
      %put ************************************************************;
      %put ERROR: Database not active. Check your log for prior errors;
      %put ERROR: Target &Objective Reports Not Run;
      %put ************************************************************;
      %goto exit1;
  %end;

 /*----------------------------------------------------------------------------
  | Verify that CPSLMCRP exists before proceeding.
  *--------------------------------------------------------------------------*/
  %let SLMDIRCHK = %CPSEP(&CPSLMCRP)slm;
  %if (&CPOPSYS ne MVS) and (%sysfunc(fileexist(&SLMDIRCHK))=0) %then %do;
      %put ************************************************************;
      %put ERROR: &SLMDIRCHK Does not exist. Check your log for previous;
      %put ERROR: errors. ;
      %put ************************************************************;
      %goto exit1;
  %end;

 /*----------------------------------------------------------------------------
  | Set macro variables used by the Target Reports.
  |
  | The Target reports below can be Availability, Response Time or
  | Throughput reports. The Report name (CPRPTNM), titles, labels and
  | variables graphed depend on the parameter provided at macro invocation
  | time.
  |
  | These colors are used below.
  | CXFAF8ED light beige for missing values
  | CXCC0066 red
  | CXFFCC00 yellow
  | CX669966 green
  | CX336699 blue
  *--------------------------------------------------------------------------*/
  %if &Objective = availability %then %do;
          %let desc = Availability;
          %let type = AV;
          %let dirname = slmta;
          %let catname = slmta;
          %let TargetBas = ATGTBAS;
          %let TargetPFR = ATGTPFR;
          %let TargetOK = ATGTOK;
          %let TargetVar = ATARGET;
          %let ScoreVar = ASCORE;
          %let IndVar = ASLI;
          %let best = 10;
          %let worst = -10;
          %let IndFmt = 12.2;
          %let ScoreFmt = 12.2;
          %let TrgtFmt = 12.2;
   %end;
   %else %if &Objective = response %then %do;
          %let desc = Response Time;
          %let type = RT;
          %let dirname = slmtr;
          %let catname = slmtr;
          %let TargetBas = RTGTBAS;
          %let TargetPFR = RTGTPFR;
          %let TargetOK = RTGTOK;
          %let TargetVar = RTARGET;
          %let ScoreVar = RSCORE;
          %let IndVar = RSLI;
          %let best = -10;
          %let worst = 10;
          %let IndFmt = 12.2;
          %let ScoreFmt = 12.2;
   %end;
   %else %if &Objective = throughput %then %do;
          %let desc = Throughput;
          %let type = TH;
          %let dirname = slmtt;
          %let catname = slmtt;
          %let TargetBas = TTGTBAS;
          %let TargetPFR = TTGTPFR;
          %let TargetOK = TTGTOK;
          %let TargetVar = TTARGET;
          %let ScoreVar = TSCORE;
          %let IndVar = TSLI;
          %let best = 10;
          %let worst = -10;
          %let IndFmt = 12.2;
          %let ScoreFmt = 12.2;
   %end;
   %else %do;
      %put ***************************************************;
      %put ERROR: Valid parameters are;
      %put Availability, Respose and Throughput  ;
      %put ***************************************************;
      %goto exit1;
   %end;

 /*----------------------------------------------------------------------------
  | The Target Format below is used by the thumbnail (GIF) version of a bar
  | chart below. The string values for 1 and 0 are abbreviated because a bar
  | chart with a single bar cannot fit larger strings. THe larger JAVA version
  | of the bar chart uses the strings 'Target Met' and "Target Missed' that are
  | passed to the applet.  |
  *--------------------------------------------------------------------------*/
  proc format;
      value TrgtFmt
        1 = 'Tgt Met'
        0 = 'Tgt Miss'
       -1 = 'Scheduled Outage'
       -2 = 'Excused Outage'
       -3 = 'UnScheduled Outage';
  run;

 /*----------------------------------------------------------------------------
  | %CPWEBINI initializes the directory, folder, or PDS before creating
  | the reports.
  *--------------------------------------------------------------------------*/
  %cpwebini(cat = work.&catname, dir = &cpslmcrp.&dirname,
      WEBSTYLE = &webstyle);

 /*----------------------------------------------------------------------------
  | Report name: TRAVHR01 or TRRTHR01 or TRTHHR01
  | Description: Detail Outage Plot
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.detail))ne 0) %then %do;
  %LET CPRPTNM = TR&Type.HR01;
  TITLE1 &Desc Targets and Outages;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    detail
    ,&TargetPFR,
    ,TYPE = SCATTER
    ,BY = parent node
    ,WHERE = (&TargetPFR gt .Z)
    ,REDLVL = admin
    ,BEGIN = latest
    ,END = latest
    ,LTCUTOFF = &slmcutoff
    ,STMTOPT = cframe = &color
    ,PERIOD = asis
    ,VAXIS = label = none order = (-4 to 2 by 1) value = (" "
          "Unscheduled Outage" "Excused Outage" "Scheduled Outage"
          "Target Missed" "Target Met"  " ")
    ,VREF = %str(-3) %str(-2) %str(-1) 0 1 cvref = (black)
    ,VZERO = Yes
    ,UNIFORM = Yes
    ,LABELS = (Node = "Node Name"
               DATETIME = "Time")
    ,PALETTE = PGMLIB.PALETTE.CARNIVLS
    ,OUTDESC = Hourly Outages
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );

 /*----------------------------------------------------------------------------
  | Report name: TRAVHR02 or TRRTHR02 or TRTHHR02
  | Description: Detail Outage Chart
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = TR&Type.HR02;
  TITLE1 &Desc Targets and Outages;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPCCHRT(
    detail
    ,DURATION,
    ,GROUP=&TargetOK
    ,SUBGROUP=&TargetPFR
    ,BY = parent node
    ,WHERE = (&TargetPFR gt .Z)
    ,REDLVL = admin
    ,BEGIN = latest
    ,END = latest
    ,LTCUTOFF = &slmcutoff
    ,STMTOPT = cframe = &color
    ,PERIOD = hour
    ,STAT = SUM
    ,AXIS = '00:00't to '24:00't by '4:00't
    ,TYPE = VBAR3D
    ,YVAL = 16
    ,FORMATS = (&TargetPFR = TrgtFmt.
                &TargetOK = TrgtFmt.
                DURATION = TIME5.)
    ,LABELS = (&TargetPFR = "Reason"
               &TargetOK = "Status"
               Duration = "Duration"
               Node = "Node Name")
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Hourly Outages
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &javdevice
    ,WEBSTYLE = &webstyle
    );

 /*----------------------------------------------------------------------------
  | Report name: TRAVHR03 or TRRTHR03 or TRTHHR03
  | Description: Detail Outage Pie
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = TR&Type.HR03;
  TITLE1 &Desc Targets and Outages;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
 %CPCHART(
    detail
    ,&TargetPFR,
    ,DURATION,
    ,BY = parent node
    ,WHERE = (&TargetPFR gt .Z)
    ,REDLVL = admin
    ,BEGIN = latest
    ,END = latest
    ,LTCUTOFF = &slmcutoff
    ,STMTOPT = percent = arrow
    ,PERIOD = hour
    ,STAT = SUM
    ,ORDER = midpoint
    ,TYPE = PIE
    ,YVAL = 16
    ,FORMATS = (&TargetPFR = TrgtFmt.)
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,OUTDESC = Hourly Outages
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &javdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.detail exists */

 /*----------------------------------------------------------------------------
  | Report name: TRAVDY01 or TRRTDY01 or TRTHDY01
  | Description: Daily Target Plot
  *--------------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.day))ne 0) %then %do;
  %LET CPRPTNM = TR&Type.DY01;
  TITLE1 &Desc Target;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    day
    ,&TargetOK,
    ,TYPE = SCATTER
    ,BY = parent node
    ,WHERE = (&TargetOK gt .Z)
    ,REDLVL = admin
    ,BEGIN = latest-31
    ,END =  latest-&offset
    ,STMTOPT = cframe = &color
    ,PERIOD = asis
    ,VAXIS = label = none order = (-1 0 to 2 by 1)
             value = ("  "  "Target Missed" "Target Met" "  ")
    ,VREF = 0 1 cvref = (black)
    ,VZERO = Yes
    ,UNIFORM = Yes
    ,LABELS = (DATETIME = "DATE")
    ,PALETTE = PGMLIB.PALETTE.CARNIVLS
    ,OUTDESC = Daily Targets
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.day exists */

 /*-------------------------------------------------------------------*
  | Report name: TRAVMN01 or TRRTMN01 or TRTHMN01
  | Description: Monthly Target Plot
  *-------------------------------------------------------------------*/
  %if (%sysfunc(exist(admin.month))ne 0) %then %do;
  %LET CPRPTNM = TR&Type.MN01;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPPLOT1(
    month
    ,&TargetOK,
    ,TYPE = SCATTER
    ,BY = parent node
    ,WHERE = (&TargetVar gt .Z)
    ,REDLVL = admin
    ,BEGIN = earliest
    ,END = latest
    ,STMTOPT = cframe = &color
    ,PERIOD = month
    ,VAXIS = order = (-1 0 to 2 by 1) label = none
             value = ("  "  "Target Missed" "Target Met" "  ")
    ,HAXIS = minor = none
    ,VREF = 0 1 cvref = (black)
    ,VZERO = Yes
    ,UNIFORM = Yes
    ,LABELS = (DATETIME = "MONTH")
    ,PALETTE = PGMLIB.PALETTE.CARNIVLS
    ,OUTDESC = Monthly Targets
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &gifdevice
    ,WEBSTYLE = &webstyle
    );

 /*----------------------------------------------------------------------------
  | Report name: TRAVMN02 or TRRTMN02 or TRTHMN02
  | Description: Monthly Target vs. Score Chart
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = TR&Type.MN02;
  TITLE1 &Desc Target vs. Score ;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPCCHRT(
    month
    ,&TargetVar,
    ,&ScoreVar,
    ,BY = NODE PARENT
    ,REDLVL = ADMIN
    ,WHERE = %nrstr(&ScoreVar gt .Z and &TargetBas eq 'SCORE')
    ,GROUP = DATE
    ,TYPE = VBAR3D
    ,YVAL=24
    ,BEGIN = earliest
    ,END = latest
    ,STMTOPT = cframe = &color
    ,AXIS = axis2
    ,PATTRNID = midpoint
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,LABELS=(NODE = "Node"
             PARENT = "Parent"
             DATE = "Date"
             &TargetVar = "Target"
             &ScoreVar = "Score")
    ,FORMATS = (&TargetVar = &ScoreFmt
                &ScoreVar = &ScoreFmt)
    ,OUTDESC = Monthly Targets
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = JAVA
    ,WEBSTYLE = &webstyle
    );

 /*----------------------------------------------------------------------------
  | Report name: TRAVMN03 or TRRTMN03 or TRTHMN03
  | Description: Monthly Target vs. Indicator Chart
  *--------------------------------------------------------------------------*/
  %LET CPRPTNM = TR&Type.MN03;
  TITLE1 &Desc Target vs. Indicator ;
  TITLE2 h = 1.5 " #byval(parent) ";
  TITLE3 h = 1.5 " #byval(node) ";
  %CPCCHRT(
    month
    ,&TargetVar,
    ,&IndVar,
    ,BY = NODE PARENT
    ,REDLVL = ADMIN
    ,WHERE = %nrstr(&IndVar gt .Z and &TargetBas eq 'SLI')
    ,GROUP = DATE
    ,TYPE = VBAR3D
    ,YVAL=24
    ,BEGIN = earliest
    ,END = latest
    ,STMTOPT = cframe = &color
    ,AXIS = axis2
    ,PATTRNID = midpoint
    ,PALETTE = PGMLIB.PALETTE.CARNIVAL
    ,LABELS=(NODE = "Node"
             PARENT = "Parent"
             DATE = "Date"
             &TargetVar = "Target"
             &IndVar = "Indicator")
    ,FORMATS = (&TargetVar = &IndFmt
                &IndVar = &IndFmt)
    ,OUTDESC = Monthly Targets
    ,OUTMODE = web
    ,HTMLDIR = &cpslmcrp.&dirname
    ,IMAGEDIR = &cpslmcrp.&dirname
    ,OUTLOC = work.&catname
    ,LARGEDEV = &javdevice
    ,WEBSTYLE = &webstyle
    );
   %end; /* Verify admin.month exists */
  %exit1:
 %mend RptTarget;



 /*----------------------------------------------------------------------------
  | #5: This macro, %DrillDown, generates the drill down reports. It generates
  | daily, monthly and yearly reports. By default it produces reports for the
  | latest day, latest month and latest year. Modify the %daterange macro
  | (described below) to modify the default date range.
  *--------------------------------------------------------------------------*/

  %let cpsep=%cpsep();

 %macro DrillDown;

 /*----------------------------------------------------------------------------
  | Check Return code from %CPSLMCON before proceeding.
  *--------------------------------------------------------------------------*/
  %if &slmrc gt 0 %then %do;
      %put ************************************************************;
      %put ERROR: Database not active. Check your log for prior errors;
      %put ERROR: Drilldown Reports Not Run;
      %put ************************************************************;
      %goto exit1;
  %end;

 /*----------------------------------------------------------------------------
  | Verify that CPSLMCRP exists before proceeding.
  *--------------------------------------------------------------------------*/
  %let SLMDIRCHK = %CPSEP(&CPSLMCRP)main;
  %if (&CPOPSYS ne MVS) and (%sysfunc(fileexist(&SLMDIRCHK))=0) %then %do;
      %put ************************************************************;
      %put ERROR: &SLMDIRCHK Does not exist. Check your log for previous;
      %put ERROR: errors. Drilldown Reports Not Run.;
      %put ************************************************************;
      %goto exit1;
  %end;


 %global contract contractnode;
 %local slmIdx;


  data _null_;
      set slm.contract(where=(id=&cpslmcid));
      call symput('CONTRACTNAME', name);
      call symput('CONTRACTNODE', tablename);
  run;

  %*cpslmcal( indicator1=asli,desc1=Availability, format1=best8.,
            indicator2=rsli,desc2=Response Time, format2=time8.,
            indicator3=tsli,desc3=Throughput, format3=best8.0,
            indicator4=zsli,desc4=Composite, format4=best8.2,
            node=&contractnode, date=&slmrptdt);

  filename rptcode catalog 'work.test.runcode.source';

  /* Execute Daily Reports */
  %do slmIdx = 0 %to &Ndays;
    %let slmrptdt = &&DayRptDate&slmIdx;
    data _null_;
      file rptcode;
      set admin.contractStructure;
      put ' %cpslmnot(node=' tablename  ",date=&slmrptdt, period=DAY );";
      run;
    %inc rptcode;

    %cpslmday(aformat=f10.3, rformat=f10.3, tformat=f10.3,
           cformat=f10.3,date=&slmrptdt);

    data _null_;
      file rptcode;
      set admin.contractStructure;
      put '%cpslmind(node=' tablename  ",date=&slmrptdt);";
      run;
    %inc rptcode;
  %end;

  /* Execute Monthly Reports */
  %do slmIdx = 0 %to &NMonths;
    %let slmrptdt = &&MonthRptDate&slmIdx;
    data _null_;
      file rptcode;
      set admin.contractStructure;
      put ' %cpslmnot(node=' tablename  ",date=&slmrptdt, period=MONTH );";
    run;
    %inc rptcode;

    %cpslmptd(period=MONTH, aformat=f10.3, rformat=f10.3, tformat=f10.3,
           cformat=f10.3, date=&slmrptdt);
  %end;

  /* Execute Yearly Reports */
  %do slmIdx = 0 %to &Nyears;
    %let slmrptdt = &&YearRptDate&slmIdx;
    data _null_;
      file rptcode;
      set admin.contractStructure;
      put ' %cpslmnot(node=' tablename  ",date=&slmrptdt, period=YEAR );";
      run;
    %inc rptcode;

    %cpslmptd(period=YEAR,aformat=f10.3, rformat=f10.3, tformat=f10.3,
           cformat=f10.3, date=&slmrptdt);
  %end;

  %cpslmout();

  %cpslmctr(contractid=&cpslmcid);

  /*---------------------------------------------------------------------
   | CUSTOMIZE: (Optional) -  This report is experimental.
   | Add report showing whether the contract measurements
   | are in compliance with the agreements specified in the contract
   | requirements.  This reports is turned off by default.   Enable it
   | by removing the '*' from the macro call, which makes it a comment.
   *--------------------------------------------------------------------*/

   * The following report shows all nodes within a single
     contract;
   %*cpslmcpl(date=&slmrptdt, type=ALLNODES,
              outfile=&cpslmcrp.&cpsep.compliance.htm,
              title=Compliance for all nodes in contract);

  %exit1:

 %mend DrillDown;


  /*---------------------------------------------------------------------------
   | #6: This macro, %CreateDir, creates the directory structure on Windows or
   | UNIX servers if it does not already exist.
   *-------------------------------------------------------------------------*/
  %macro CreateDir;
    %if (&CPOPSYS ne MVS) and (%sysfunc(fileexist(&CPSLMCRP))=0) %then %do;
      %let slmrc=.;
      %if &CPOPSYS=OSYS %then %do;
        %let path= /bin/ ;
        %let target=&CPSLMCRP;
        %let option = -p ;
        %CPXEQCMD( &path.mkdir &option &target; ,
           failif=line ne "0", _rc=slmrc );

      %end;
      %else %do;
        %let target="&CPSLMCRP";
        %let path = %str();
        %let option = %str();
        %CPXEQCMD( &path.mkdir &option &target; ,
           failif=line ne "0", _rc=slmrc );
      %end;
      %if &slmrc ne 0 %then %put ERROR: Create &CPSLMCRP failed.;
    %end;
  %mend CreateDir;


 /*---------------------------------------------------------------------------
  | #7: This macro, %InitGallery, initializes the directory structure needed
  | by the graph reports.
  *--------------------------------------------------------------------------*/
  %macro InitGallery;
    %if (%sysfunc(fileexist(&CPSLMCRP.web))=0) %then %do;
    /*------------------------------------------------------------------------
     | Execute the macro %CreateDir to create the directory structure.
     *-----------------------------------------------------------------------*/
      %CreateDir;
    /*------------------------------------------------------------------------
     | Check the return code from %CPSLMCON before proceeding.
     *-----------------------------------------------------------------------*/
      %if (&slmrc ne 0) or (%sysfunc(fileexist(&cpslmcrp)) eq 0) %then %do;
         %put ******************************************************;
         %put ERROR: Connection to contract database failed ;
         %put ERROR: or directory structure does not exist. ;
         %put ERROR: Gallery tree not initialized. ;
         %put ERROR: code is : &slmrc. ;
         %put ******************************************************;
         %goto exit1;
      %end;

      /*----------------------------------------------------------------------
       | This call to the %CPHTREE macro creates the gallery tree that is
       | defined in SLMLIB.SLMENV.SLMTREE.SOURCE.
       *---------------------------------------------------------------------*/
       %CPHTREE(
       SUPERLOC=&CPSLMCRP
       ,LISTCLR=YES
       ,SMLSPACE=%quote((TRK,(2,5,12)))
       ,BIGSPACE=%quote((CYL,(1,2,96)))
       ,DSPARMS=%quote(DSORG=PO,RECFM=VB,BLKSIZE=6160,LRECL=6156)
       ,SEPARATR=!
       ,SUBLOC=slm
       ,CAT=SLMLIB.SLMENV.SLMTREE.SOURCE
       ,TITLE2=SLM Gallery
       ,WEBSTYLE=&WEBSTYLE
       );
    %end;
    %exit1:
  %mend InitGallery;


  /*------------------------------------------------------------------------
   | #8: This macro, %InitDrill, sets up the directories that are used for
   | the "drill-down" set of reports.  It uses primarily the same common
   | values as the gallery reports with the exception of the contract id.
   *-----------------------------------------------------------------------*/
  %let contractid=&cpslmcid;
  %macro InitDrill;
   /*-----------------------------------------------------------------------
    | Execute the macro %CreateDir to create the directory structure.
    *----------------------------------------------------------------------*/
   %CreateDir;
   /*-----------------------------------------------------------------------
    | Check the return code from %CPSLMCON before proceeding.
    *----------------------------------------------------------------------*/
    %if (&cpopsys eq MVS) %then %do;
      %put ******************************************************;
      %put ERROR: &cpopsys is not yet supported for IT Service ;
      %put ERROR: Level Management Drill-Down reporting;
      %put ******************************************************;
      %goto exit1;
    %end;

    %if (&slmrc ne 0) or (%sysfunc(fileexist(&cpslmcrp)) eq 0) %then %do;
      %put ******************************************************;
      %put ERROR: Connection to contract database failed ;
      %put ERROR: or directory structure does not exist. ;
      %put ERROR: Drilldown tree not initialized. ;
      %put ERROR: code is : &slmrc. ;
      %put ******************************************************;
      %goto exit1;
    %end;

    %if &cpopsys=OSYS %then %do;
      %let batfile=slmdirs.cmd;
      %let path= /bin/ ;
    %end;
    %else %if &cpopsys=WIN %then %do;
      %let batfile=slmdirs.bat;
      %let path = %str();
    %end;

    filename mkdirs "&cpslmcrp&batfile";

    data _null_;
         file mkdirs;
         if _n_=1 then do;
    %if &cpopsys=OSYS %then %do;
            put "&path.mkdir &cpslmcrp.main";
    %end;
    %else %if &cpopsys=WIN %then %do;
            cmd = "&path.mkdir "||'"'||"&cpslmcrp.main"||'"    ';
            put cmd;
    %end;
         end;
         set admin.contractStructure;
    %if &cpopsys=OSYS %then %do;
         cmd = "&path.mkdir &cpslmcrp"  || trim(tablename) ;
    %end;
    %else %if &cpopsys=WIN %then %do;
         cmd = "&path.mkdir "||'"'||"&cpslmcrp"|| trim(tablename) ||'"';
    %end;

         put cmd;
         run;

    %if (&CPOPSYS ne MVS) and
           (%sysfunc(fileexist(&CPSLMCRP)) ne 0) %then %do;
       %let batfilepath=;
       %if &CPOPSYS=OSYS %then %do;
          %let slmrc=.;
          %let batfilepath=&cpslmcrp&batfile;
          %CPXEQCMD( chmod 755 &batfilepath; ,
                   failif=line ne "0", _rc=slmrc );
          %put chmod return code is : &slmrc;
          %if &slmrc ne 0 %then %do;
              %put ERROR: Changing permissions on &cpslmcrp&batfile failed.;
              %goto exit1;
              %end;
          %end;
       %else %do;  %* Windows;
          %let batfilepath="&cpslmcrp&batfile";
          %end;

       %let slmrc=.;

       %CPXEQCMD( &batfilepath; ,
                failif=line eq "0", _rc=slmrc );
       %put slmdirs.bat return code is : &slmrc;
       %if &slmrc ne 0 %then %do;
           %put ERROR: Executing &batfilepath failed.;
           %goto exit1;
       %end;
    %end;


     /* If the main directory is empty, then initialize it. */
     %if (%sysfunc(fileexist(&CPSLMCRP.main))=1) %then %do;
         %let fnrc=%sysfunc(filename(maindir,&CPSLMCRP.main));
         %let maindid=%sysfunc(dopen(&maindir));
         %let maincount=%sysfunc(dnum(&maindid));
         %let mcrc=%sysfunc(dclose(&maindid));
         %if (&maincount ne 0) %then %do;
             %goto exit1;
         %end;
     %end;

    %cpwebini(dir=&cpslmcrp.main,webstyle=&webstyle);

    %if &cpopsys = OSYS %then %let copymode=ASCII;
        %else %let copymode=EBCDIC;
    %cpentcpy(from=slmcss,      fromcat=slmlib.slmenv,
           to=  itrmslm.css, toloc=&cpslmcrp.main,
           type=css,
           mode=&copymode,
           replace=yes);

    %cpentcpy(from=htmbannr htmindex,  fromcat=slmlib.slmenv,
              to=banner index, toloc=&cpslmcrp.main,
              type=htm,
              replace=yes);

    %cpentcpy(fromcat = slmlib.slmenv,
              from    = daternjs,
              toloc   = %quote(&cpslmcrp)main%cpsep(),
              to      = daterng,
              type    = js,
              replace = no);

    %cpgifcpy(contract sla service compnent slmnotes bargraph,
             inlib=slmlib, incat=slmenv, superloc=&cpslmcrp.main);

  %exit1:
  %mend InitDrill;



 /*----------------------------------------------------------------------------
  | #9: This macro, %RptAllContracts, will read your environment data and
  | obtain the contract IDs for all your active contracts. This information
  | is used below to loop through all your active contracts.
  *--------------------------------------------------------------------------*/
 %macro RptAllContracts;
  %let slmactives = 0;
   data work.RptCon;
     merge slm.contract slm.contractpdb end=last;
         by id;
     if status eq 'ACTIVE' and deleteflag = 'N' then do;
       slmactives+1;
       call symput('id'||trim(left(put(slmactives,8.))),
           trim(left(put(id,8.))));
       call symput('reportPath'||trim(left(put(slmactives,8.))), reportPath);
       call symput('contractPath'||trim(left(put(slmactives,8.))), Path);
     end;
    if last then call symput('slmactives',trim(left(put(slmactives,8.))));
   run;
 %mend RptAllContracts;

 /*----------------------------------------------------------------------------
  | #10: This macro, %RptOneContract, will read your environment data and
  | obtain the contract IDs for all your active contracts. This information
  | is used below to loop through all your active contracts.
  *--------------------------------------------------------------------------*/
 %macro RptOneContract(contractId=,contractName=);
   %global id1;
   %global reportPath1;
   %global contractPath1;
   %let slmactives = 1;

   %if &contractId eq %str() and &contractName eq %str() %then %do;
     %put ERROR: ContractId or ContractName required;
     %let &_rc = 4;
         %goto exit;
   %end;

   data work.RptCon;
     merge slm.contract slm.contractpdb end=last;
         by id;
       if id eq "&ContractID" then do;
         call symput('id1', id);
         call symput('reportPath1', reportPath);
         call symput('contractPath1', Path);
         output;
         stop;
      end;
      if name eq "&Contractname" then do;
         call symput('id1', id);
         call symput('reportPath1', reportPath);
         call symput('contractPath1', Path);
         output;
         stop;
      end;
      if last then put
         'ERROR: Contract ID or Contract Name not found ';
   run; quit;
 %exit: ;
 %mend RptOneContract;

/*----------------------------------------------------------------------------
  | #11: This macro, %DateRange, reads your contract database and determines
  | the earliest and latest date for which there is data. It creates a list
  | of dates with which your daily, monthly and yearly reports will be called
  | from the macro %DrillDown. The default values are latest and latest.
  *--------------------------------------------------------------------------*/

 %macro DateRange(DrillBegdate=latest, DrillEndDate=latest);
  %global Ndays;   %let Ndays = 0;
  %global Nmonths; %let NMonths = 0;
  %global Nyears;  %let Nyears = 0;
  %global offset;  %let offset = 0;
  %global earliestdate latestdate;
  %local slmIdx;
  %let DrillBegDate = %lowcase(&DrillBegDate);
  %let DrillEndDate = %lowcase(&DrillEndDate);

  /* Obtain the earliest and latest date from the database. These dates
     will be used by the drilldown reports if a specific date isn't
     passed in. An offset will be calculated, which may be used by the
     drilldown reports and by the gallery reports. */
  proc sql noprint;  create table work.daterange as
    select min(edatm) as earliestDatetime,
           max(ldatm) as latestdatetime
      from dictlib.tredinfo
           where (tablenm contains 'C'
           or tablenm contains 'L'
           or tablenm contains 'S'
           or tablenm contains 'N') and
           redlevel eq 'DETAIL' and
           edatm ne . and ldatm ne .;
  run;
  data work.daterange&slmcontractid ;
    set work.daterange ;
    earliestDate = datepart(earliestDatetime);
    latestDate = datepart(latestDatetime);
    /* Adjust the latest date and set offset to 1
           if latest time is less than slmcutoff */
    LatestTime=timepart(latestDatetime);
    if LatestTime < "&slmcutoff"t then do;
       latestDate = latestDate - 1;
           call symput('offset', 1);
    end;

    BegDate = symget('DrillBegDate');
    EndDate = symget('DrillEndDate');

    if BegDate eq 'latest' then do;
       earliestdate = latestdate;
       earliestdatetime = latestdatetime;
    end;
    if EndDate eq 'earliest' then do;
       latestdate = earliestdate;
       latestdatetime = earliestdatetime;
    end;
    BegDate = put(earliestDate,date9.);
    EndDate = put(latestDate,date9.);
    call symput('earliestdate',put(earliestDate,date9.));
    call symput('latestdate',put(latestDate,date9.));

    Ndays = intck('DAY',earliestDate, latestDate);
    call symput('Ndays',Ndays);
    Nmonths = intck('MONTH',earliestDate, latestDate);
    call symput('Nmonths',Nmonths);
    Nyears = intck('YEAR',earliestDate, latestDate);
    call symput('Nyears',Nyears);
  run;

  /* If latest and earliest were not passed in, then use the actual
         dates that were passed in instead. */
  %if (&DrillBegDate ne latest) and (&DrillEndDate ne earliest)and
      (&DrillEndDate ne latest) and (&DrillEndDate ne earliest) %then %do;
    data work.daterange&slmcontractid;
      begDate = symget('DrillBegDate');
      endDate = symget('DrillEndDate');
      earliestdate = input (symget ('DrillBegDate'), date9.);
      latestdate = input (symget ('DrillEndDate'), date9.);

      call symput('earliestdate',put(earliestDate,date9.));
      call symput('latestdate',put(latestDate,date9.));

      Ndays = intck('DAY',earliestDate, latestDate);
      call symput('Ndays',Ndays);
      Nmonths = intck('MONTH',earliestDate, latestDate);
      call symput('Nmonths',Nmonths);
      Nyears = intck('YEAR',earliestDate, latestDate);
      call symput('Nyears',Nyears);
    run;
  %end;

  %do slmIdx = 0 %to &Ndays;
    %global DayRptDate&slmIdx;
  %end;
  %do slmIdx = 0 %to &NMonths;
    %global MonthRptDate&slmIdx;
  %end;
  %do slmIdx = 0 %to &Nyears;
     %global YearRptDate&slmIdx;
  %end;
  data _null_;
    %if %eval(&Ndays) eq 0 %then %do;
          day = "&latestdate"d;
          day2 = put(day,date9.);
          call symput('DayRptDate0',day2);
        %end;
    %else %if %eval(&Ndays) > 0 %then %do;
      %do dayIdx = 0 %to &Ndays;
            day = intnx("DAY","&earliestdate"d,+&dayIdx,'end');
            day2 = put(day,date9.);
            call symput('DayRptDate'||trim(left(put(&dayIdx,8.))),day2);
      %end;
        %end;
        %if %eval(&NMonths) eq 0 %then %do;
          month = "&latestdate"d;
          month2 = put(month,date9.);
          call symput('MonthRptDate0',month2);
        %end;
    %else %if %eval(&NMonths) > 0 %then %do;
      %do monIdx = 0 %to %eval(&Nmonths-1);
             month = intnx("MONTH","&earliestdate"d,+&monIdx,'end');
             month2 = put(month,date9.);
             call symput('MonthRptDate'||trim(left(put(&monIdx,8.))),month2);
      %end;
          month = "&latestdate"d;
          month2 = put(month,date9.);
          call symput('MonthRptDate'||trim(left(put(&Nmonths,8.))),month2);
    %end;
        %if %eval(&NYears) eq 0 %then %do;
          year = "&latestdate"d;
          year2 = put(year,date9.);
          call symput('YearRptDate0',year2);
        %end;
    %if %eval(&Nyears) > 0 %then %do;
          %do yearIdx = 0 %to %eval(&nyears-1) ;
             year = intnx("YEAR","&earliestdate"d,+&yearIdx,'end');
             year2 = put(year,date9.);
             call symput('YearRptDate'||trim(left(put(&yearIdx,8.))),year2);
      %end;
          year = "&latestdate"d;
          year2 = put(year,date9.);
          call symput('YearRptDate'||trim(left(put(&Nyears,8.))),year2);
    %end;
    run; quit;
  %exit:
 %mend DateRange;


 /*----------------------------------------------------------------------------
  | BELOW IS WHERE ALL THE WORK BEGINS. Below we call the macro %CPSLMENV to
  | start your enviroment. Next we call the macro %RunReports to
  | loop throught all your active contracts. It connects to then executes the
  | reports for each active contract.
  *--------------------------------------------------------------------------*/

 /*----------------------------------------------------------------------------
  | Execute the %CPSLMENV macro to start your SLM Environment once.
  *--------------------------------------------------------------------------*/
  %CPSLMENV(environmentDBPath=&SlmEnvPath,
     ShareService=&slmShareService, ShareUser=&slmShareUser,
     SharePassword=&slmSharePassword, action=start, _rc = slmrc);
    %put Return code from CPSLMENV is: &slmrc;

 /*----------------------------------------------------------------------------
  | CUSTOMIZE: (Optional)
  | Execute the %RptAllContracts macro to obtain the information needed to
  | generate reports for all the ACTIVE contracts in your environment. If you
  | wish to run reports for a single contract, then comment the call to this
  | macro and execute the macro, %RptOneContract instead. See below.
  *--------------------------------------------------------------------------*/
  %RptAllContracts;

  /*----------------------------------------------------------------------------
  | CUSTOMIZE: (Optional)
  | Execute the %RptOneConract macro to generate reports for the single contract
  | name or contract id specified. The call to this macro is commented out by
  | default. Calling %RptOneContract allows you to run reports for a contract
  | that is INACTIVE.
  *--------------------------------------------------------------------------*/
  %*RptOneContract(ContractId=1);
  %*RptOneContract(Contractname=Network Service Contract);

 /*----------------------------------------------------------------------------
  | Define the macro %RunReports, which will loop through all
  | active contracts and run the reports.
  *--------------------------------------------------------------------------*/
  %macro RunReports;

  %global cpopsys;
  %if &cpopsys = MVS %then %let cpopsys = OSYS;

  %local slmIdx;
  /*----------------------------------------------------------------------------
   | Check the return code from %CPSLMENV before proceeding.
   *--------------------------------------------------------------------------*/
   %if &slmrc gt 0 %then %do;
      %put ************************************************************;
      %put ERROR: Environment was not started. Check your log for prior errors;
      %put ERROR: Check the value for SlmEnvPath;
      %put ************************************************************;
      %goto exit0;
   %end;

   %if &slmactives > 0 %then %do;
     /*------------------------------------------------------------------------
      | For the specified set of contracts: Connect, initialize directory
      | structures (if needed), and run the drilldown and gallery reports.
      *-----------------------------------------------------------------------*/
     %do slmIdx = 1 %to &slmactives;
       %let slmContractID=&&id&slmIdx;
       %let CPSLMCRP = %CPSEP(&&reportPath&slmIdx);

      /*------------------------------------------------------------------------
       | Execute the %CPSLMCON macro to connect to each active contract found.
       *----------------------------------------------------------------------*/
       %CPSLMCON(contractid=&slmContractID, _RC = slmrc);
       %put Return code from CPSLMCON is: &slmrc;

       /* turn syntaxcheck mode off if set by earlier contract */
       options no$syntaxcheck replace obs=max;

       /*----------------------------------------------------------------------
        | Execute the %InitGallery and %InitDrill macros to create the directory
        | structure needed by the gallery and drilldown reports.
        *---------------------------------------------------------------------*/
        %InitDrill;
        %InitGallery;

       /*-----------------------------------------------------------------------
        | CUSTOMIZE: (Optional)
        | Set the value for slmcutoff equal to the time that you wish to use for
        | adjusting your latest date. The default value of 6:15AM means that
        | the latest date will be rolled back by one date if there is no data
        | after 6:15AM for the latest date. slmcutoff is used by the gallery
        | reports and by the drill down reports. To disable slmcutoff change the
        | value to 00:00
        *---------------------------------------------------------------------*/
        %let SLMCUTOFF = 06:15;

       /*----------------------------------------------------------------------
        | CUSTOMIZE: (Optional)
        | Set the Begin and End dates for the drilldown reports. The default is
        | to run the daily, monthly and yearly reports for the latest day,
        | latest month and latest year.  The list below shows valid values.
        | When specifying a date range, please use the date format shown below.
        |
        | %DateRange(DrillBegdate=latest, DrillEndDate=latest);
        | %DateRange(DrillBegdate=earliest, DrillEndDate=earliest);
        | %DateRange(DrillBegdate=earliest, DrillEndDate=latest);
        | %DateRange(DrillBegdate=10Aug2003, DrillEndDate=15Aug2003;
        *---------------------------------------------------------------------*/
        %DateRange(DrillBegdate=latest, DrillEndDate=latest);

       /*-----------------------------------------------------------------------
        | Execute the %DrillDown macro to generate the drill down reports.
        *---------------------------------------------------------------------*/
        %DrillDown;

       /*-----------------------------------------------------------------------
        | CUSTOMIZE: (Recommended)
        | Comment and uncomment the macro calls below to execute the
        | desired set of gallery reports. The %RptInd macro generates Indicator
        | reports for all nodes. The %RptScore macro generates Score reports
        | for all nodes that have scores assigned to them. The %RptARTScore
        | generates reports that compare Availability, Response Time and
        | Throughput Scores in a single graph. The %RptTarget macro generates
        | reports that show target status (met vs. miss) and outage information
        | for all nodes.
        *---------------------------------------------------------------------*/
        %RptInd(Objective = availability);
        %*RptInd(Objective = response);
        %*RptInd(Objective = throughput);
        %*RptInd(Objective = composite);

        %*RptScore(Objective = availability);
        %*RptScore(Objective = response);
        %*RptScore(Objective = throughput);
        %*RptARTScore;

        %*RptTarget(Objective = availability);
        %*RptTarget(Objective = response);
        %*RptTarget(Objective = throughput);


      %end;    /* end of do i = 1 to &slmactives */

      /*---------------------------------------------------------------------
       | CUSTOMIZE: (Recommended)
       | Add a report showing the status of all contracts. This report is
       | turned off by default. Enable it by removing the comment markers from
       | the beginning and ending of the following block of code, and specify
       | the path where the report should be created.
       *--------------------------------------------------------------------*/
     /*
      %let allcontractloc=c:\slm\reports\main;
      options nodsnferr;
      data work.__alldateranges;
           set
           %do i = 1 %to &slmactives;
               work.daterange&slmcontractid
           %end;
           ;
      run;
      options dsnferr;
      proc sql noprint;
          select max(latestDate) into :slmlatest from work.__alldateranges;
          quit;
      data _null_;
          x = &slmlatest;
          call symput('SLMRPTDT',put(x,date9.));
          run;

      %cpslmall(date=&slmrptdt, outdir=&allcontractloc, type=ALL );

     */

      /*---------------------------------------------------------------------
        | CUSTOMIZE: (Optional) - These reports are experimental.
        | Add report(s) showing whether the contract measurements
        | are in compliance with the agreements specified in the contract
        | requirements.  There are several variations available, these
        | are described in the comments below.  These reports are turned off
        | by default.   Enable them by removing the '*' from the macro call,
        | which makes it a comment.  Specify the location where you want the
        | report to be written in the SLMCPLDIR macro variable.
        *--------------------------------------------------------------------*/

        %let slmcpldir=c:\slm\reports\compliance;

        * The following report displays all contracts ;
        %*cpslmcpl(date=&slmrptdt, type=ALLCONTRACTS,
          outfile=&slmcpldir&cpsep.allcontracts.htm,
          title=Compliance Report for All Contracts);

        * the following report displays all contracts for a single customer;
        * You must customize the customer name.;
        * Copy the macro call and change the customer name and
          file name if you want reports for multiple customers.;
        %*cpslmcpl(date=&slmrptdt, type=CUSTOMER,
          outfile=&slmcpldir&cpsep.CustomerName.htm,
          title=All Contracts for Customer Lever,
          customer=Lever Inc);

        * The following report shows all nodes supported by
          a single contact;
        %*cpslmcpl(date=&slmrptdt, type=support,
          outfile=&slmcpldir&cpsep.ContactName.htm,
          title=All Nodes Supported by John Smith,
          supportContact=John Smith);



   %end;    /* if slmactives > 0 */
  %exit0:  /* Exit if can not start environment */
  %mend RunReports;

 /*----------------------------------------------------------------------------
  | Execute the %RunReports macro to connect and execute reports
  | for all active contracts in your environment.
  *--------------------------------------------------------------------------*/
  %RunReports;


 /*----------------------------------------------------------------------------
  | Execute the %CPSLMENV macro to stop the SLM environment.
  *--------------------------------------------------------------------------*/
  %CPSLMENV(environmentDBPath=&slmEnvPath, action=stop);
