
/*******************************************************************/
/*                                                                 */
/* CPSLMSHR                                                        */
/*                                                                 */
/*    This is an example of using a SAS/SHARE server to share an   */
/*    IT Service Level Management (ITSLM) environment database     */
/*    between multiple users or jobs.                              */
/*                                                                 */
/*    This example is not an exhaustive list of all SAS/SHARE      */
/*    functionality. Please refer to the SAS/SHARE(R) User's Guide */
/*    for complete documentation.                                  */
/*                                                                 */
/* Customization                                                   */
/*                                                                 */
/*    The only required customization is to substitute the TCP     */
/*    service name or port number which is to be used for this     */
/*    server.  If the service name is used, it must be present in  */
/*    the TCP services file for the host machine on which the SAS/ */
/*    SHARE server is to run.                                      */
/*                                                                 */
/*    Other common changes require that you first determine how    */
/*    you intend to use IT Service Level Management environment    */
/*    databases.  The primary decision points include:             */
/*                                                                 */
/*    Do ITSLM users share one main or primary environment         */
/*    database? If so, you may wish to preallocate this database.  */
/*                                                                 */
/*    Are there secondary environment databases that ITSLM users   */
/*    will want to use via SAS/SHARE? If so, you will want to      */
/*    allow dynamic addition of other libraries.                   */
/*                                                                 */
/*    What level of security is appropriate?  This should match    */
/*    the level of security required by the SLM server itself.     */
/*    That is, if your SLM server is secured and requires users    */
/*    to authenticate themselves, your SAS/SHARE server should as  */
/*    well, and vice-versa.                                        */
/*                                                                 */
/*******************************************************************/

/* Only the TCP communications method is supported in ITSLM        */
options comamid=tcp;

/* Only accept authenticated users (see also the authenticate=     */
/* option below.)  For no security, set this to '_none_'.          */
%let TCPSEC=_secure_;

/* This is an example of pre-allocating an environment database    */
libname slm 'c:\slm\environment';

/* Initiate the SAS/SHARE Server                                   */
 proc server

   /* Specify either the service name
         id=servicename
      or the port number preceded by two underscores
         id=__port
   */
   id=__4031

   /* Require users to authenticate themselves.  This should match */
   /* the setting of TCPSEC, above.  Optional authentication would */
   /* be specified by 'optional'.                                  */
   authenticate=required

   /* These are some other options you may wish to consider in some*/
   /* circumstances                                                */

   /* Use the client's security ID as the primary userid for access*/
   /* This option is only available under SAS Version 9 and above. */
   /* clientid=security                                            */

   /* If you wish to restrict users to only the preallocated       */
   /* environment database listed above, uncomment this option     */
   /* noalloc                                                      */

   /* Separate password for controlling the server via PROC OPERATE*/
   /* oapw=OPWSAS                                                  */

   /* Various logging options to track usage of the SHARE server   */
   /* acctlvl=all                                                  */
   /* log=all                                                      */
   /* msgnumber                                                    */

   ;
 run;
