%macro CPSLMCON(contractID=,
                contract=,
                _rc=);
 %*+----------------------------------------------------------------+
   | Copyright (c) 2003 by SAS Institute Inc., Cary, NC 27512-8000
   | Name:     CPSLMCON.SAS
   | Support:  CES
   | Product:  SAS IT Service Level Management
   | Language: SAS
   | Purpose:  Activate SLM Contract Database
   |
   | Parameters:
   |
   |   Name             Description
   |
   |  contractID        ID of the contract in the specified SLM environment
   |  contract          Name of the contract (easier for folks to use)
   |  _rc               [optional] Name of macro variable to contain RC
   | History: Date    action
   |          17Dec03 S0231566 Wrap CPSEP call around CPSLMCRP macro var sxm
   |
   | Notes:
   | end
   +----------------------------------------------------------------+;

   options compress=yes obs=max firstobs=1 nofmterr s=0 s2=0 user=WORK
           validvarname = UPCASE;

   %if %substr(&sysver,1,1) eq 9 %then %do;
      options noquotelenmax;
   %end;

   %******************************* ;
   %* Macro variable declarations * ;
   %******************************* ;
   %global _SLMrc;            %* ITSLM global return code variable ;
   %global SLMDEBUG;          %* ITSLM global debug flag ;
   %global cppmrc;            %* ITMS Core global return code variable ;
   %global cproot;            %* ITMS Core software root ;
   %global cpsow;             %* ITMS Core needs this to be global ;
   %global cpslmcid;          %* Contract ID for later use;
   %global cpslmcnm;          %* Contract name for later use;
   %global cpslmcrp;          %* Contract report path for later use;

   %let cpslmcid=;
   %let cpslmcnm=;
   %let cpslmcrp=;

   %local  accessString;      %* System-specific readonly libname option ;

   %local  _actionParm;       %* For SCL invocation ;
   %local  _contractParm;     %* For SCL invocation ;
   %local  _debugParm         %* For SCL invocation ;
   %local  _windowPrefix;     %* For SCL invocation ;

   %local  CPSLMCON_notes;     %* save and reset ;
   %local  CPSLMCON_source;    %* save and reset ;
   %local  CPSLMCON_source2;   %* save and reset ;
   %local  CPSLMCON_mprint;    %* save and reset ;
   %local  CPSLMCON_mlogic;    %* save and reset ;
   %local  CPSLMCON_macrogen;  %* save and reset ;
   %local  CPSLMCON_symbolgen; %* save and reset ;

   %******************************************************************* ;
   %* Save off some option settings to keep the noise down in the log * ;
   %******************************************************************* ;
   %let CPSLMCON_notes     = %SYSFUNC(getoption(notes));
   %let CPSLMCON_source    = %SYSFUNC(getoption(source));
   %let CPSLMCON_source2   = %SYSFUNC(getoption(source2));
   %let CPSLMCON_mprint    = %SYSFUNC(getoption(mprint));
   %let CPSLMCON_mlogic    = %SYSFUNC(getoption(mlogic));
   %let CPSLMCON_macrogen  = %SYSFUNC(getoption(macrogen));
   %let CPSLMCON_symbolgen = %SYSFUNC(getoption(symbolgen));

   %if &SLMDEBUG eq 1 %then %do;
       options notes source source2 mprint macrogen symbolgen;
   %end;
   %else %do;
       options nonotes  nosource   nosource2 nomprint nomacrogen nosymbolgen ;
   %end;

   %let _SLMrc = 0;
   %if %length(&_rc) eq 0 %then %do;
       %local RC;
       %let _rc = RC;
   %end;

   %********************************* ;
   %* Determine host-specific stuff * ;
   %********************************* ;
   %if %cphsttyp eq MVS %then %do;
       %let accessString = %str(disp=shr);
   %end;
   %else %do;
       %let accessString = %str(access=readonly);
   %end;

   %****************************************************** ;
   %* Validate the CONTRACTID= and CONTRACT= parameters. * ;
   %* We must have one of these parameters.  The SCL     * ;
   %* code will handle verifying that whatever is given  * ;
   %* is valid.  Here we just want to make sure we have  * ;
   %* exactly one of these parameters specified.         * ;
   %****************************************************** ;
   %if ((%length(&contractID) eq 0) and
        (%length(&contract) eq 0)) %then %do;
       %let _SLMrc= 8;
       %put ERROR:(&SYSMACRONAME)  SLM2003 Neither contractid= or contract=
parameters were specified.;
       %goto EXIT;
   %end;

   %if ((%length(&contractID) gt 0) and
        (%length(&contract) gt 0)) %then %do;
       %let _SLMrc= 8;
       %put ERROR:(&SYSMACRONAME)  SLM2004 Both contractid= or contract=
parameters were specified.;
       %goto EXIT;
   %end;

   %if (%length(&contractID) gt 0) %then %do;
       %let _contractParm = CONTRACTID=&contractID;
   %end;

   %if (%length(&contract) gt 0) %then %do;
       %let _contractParm = CONTRACT='&contract';
   %end;

   %************************************************************* ;
   %* Set the AF DEBUG= parm based upon the setting of SLMDEBUG * ;
   %************************************************************* ;
   %if &slmdebug eq 1 and &SYSENV eq FORE %then %do;
      %let _debugParm = YES;
   %end;
   %else %do;
      %let _debugParm = NO;
   %end;

   %*************************************************** ;
   %* The action is hard-wired.  If we do not already * ;
   %* have an SLM libref, then we are in trouble.     * ;
   %* The SLM libref is set by the CPSLMENV macro.    * ;
   %*************************************************** ;
   %let _actionParm = ACTION=ALLOC ;

   %if %sysfunc(libref(SLM)) ne 0 %then %do;
       %let _SLMrc= 8;
       %put ERROR:(&SYSMACRONAME)  SLM2009 No SLM environment is
currently active.  Please run CPSLMENV prior to running this macro.;
       %goto EXIT;
   %end;

   %********************************************************* ;
   %* If we do not have SLMLIB then we need to run CPSLMENV * ;
   %********************************************************* ;
   %if %sysfunc(libref(SLMLIB)) ne 0 %then %do;
       %let _SLMrc= 8;
       %put ERROR:(&SYSMACRONAME)  SLM2009 Cannot locate SLM software.
Please run CPSLMENV prior to running this macro.;
       %goto EXIT;
   %end;

   %********************************* ;
   %* Turn off confounding windows  * ;
   %********************************* ;
   %if %cphsttyp eq WIN %then %do;
       %local _dmsexp;
       proc sql noprint;
          select setting into :_dmsexp from dictionary.options
             where optname='DMSEXP';
       %if &_dmsexp eq DMSEXP %then %do;
          %let _windowPrefix =
            %str( ODSRESULTS; CAN; NEXT 'EXPLORER'; CAN; );
       %end;
   %end;

   %**************************************************** ;
   %* call the SCL code (return code is set in _SLMRC) * ;
   %**************************************************** ;
   dm "&_windowPrefix afa c=slmlib.slmenv.slmbatch.scl
       title='IT Service Level Management'
       aws=YES &_actionParm &_contractParm DEBUG=&_debugParm" afa;

%EXIT:
   %let cpslmcrp = %cpsep(&cpslmcrp);

   %******************************************** ;
   %* Populate user return code macro variable * ;
   %******************************************** ;
   %if %length(&_rc) gt 0 %then %do;
       %let &_rc = &_SLMrc;
   %end;
   %put NOTE:(&SYSMACRONAME) ended with return code &_SLMrc;
   options &CPSLMCON_notes   &CPSLMCON_source &CPSLMCON_source2
           &CPSLMCON_mprint &CPSLMCON_mlogic  &CPSLMCON_macrogen
           &CPSLMCON_symbolgen ;
%mend CPSLMCON;
