%macro CPSLMENV(slmpath=,
                environmentDBPath=,
                shareService=,
                shareUser=,
                sharePassword=,
                action=,
                _rc=);
 %*+----------------------------------------------------------------+
   | Copyright (c) 2003 by SAS Institute Inc., Cary, NC 27512-8000
   | Name:     CPSLMENV.SAS
   | Support:  CES
   | Product:  SAS IT Service Level Management
   | Language: SAS
   | Purpose:  Activate SLM software and environment
   |
   | Parameters:
   |
   |   Name             Description
   |  slmpath           path to the SLM software
   |  environmentDBPath path to the SLM environment
   |  shareService      Service name (or port number) for SHARE
   |  shareUser         Userid for authentication to SHARE
   |  sharePassword     Password for authentication to SHARE
   |  action            START | STOP
   |  _rc               [optional] Name of macro var to contain RC
   |
   | Notes:
   |    The shareService= parameter is optional, and is only used if
   |    a SAS/SHARE server is used to access the environment database.
   |    The shareUser= and sharePassword= parameters are also optional
   |    and are specified for purposes of authentication to the SHARE
   |    server.
   |
   | end
   +----------------------------------------------------------------+;

   options compress=yes obs=max firstobs=1 nofmterr s=0 s2=0 user=WORK
           validvarname = UPCASE;
   %if %substr(&sysver,1,1) eq 9 %then %do;
      options noquotelenmax;
      %end;

   %******************************* ;
   %* Macro variable declarations * ;
   %******************************* ;
   %global _SLMrc;        %* ITSLM global return code variable ;
   %global SLMDEBUG;      %* ITSLM global debug flag ;
   %global cppmrc;        %* ITMS Core global return code variable ;
   %global cproot;        %* ITMS Core software root ;
   %global cpsow;         %* ITMS Core needs this to be global ;

   %local  accessString;  %* System-specific readonly libname option ;

   %local  _action;           %* For upcase comparison ;
   %local  _actionParm;       %* For SCL invocation ;
   %local  _slmrootParm;      %* For SCL invocation ;
   %local  _envPathParm;      %* For SCL invocation ;
   %local  _shareServiceParm; %* For SCL invocation ;
   %local  _shareUserParm;    %* For SCL invocation ;
   %local  _sharePasswordParm;%* For SCL invocation ;
   %local  _debugParm;        %* For SCL invocation ;
   %local  _windowPrefix;     %* For SCL invocation ;

   %global  CPSLMENV_notes;      %* save and reset ;
   %global  CPSLMENV_source;     %* save and reset ;
   %global  CPSLMENV_source2;    %* save and reset ;
   %global  CPSLMENV_mprint;     %* save and reset ;
   %global  CPSLMENV_mlogic;     %* save and reset ;
   %global  CPSLMENV_macrogen;   %* save and reset ;
   %global  CPSLMENV_symbolgen;  %* save and reset ;
   %global  CPSLMENV_errorabend; %* save and reset ;
   %global  CPSLMENV_fmtsearch;  %* save and reset ;

   %************************************************************** ;
   %* Save off some option settings if we are starting a session * ;
   %************************************************************** ;
   %if %upcase(&action) eq START %then %do;
       %let CPSLMENV_notes      = %SYSFUNC(getoption(notes));
       %let CPSLMENV_source     = %SYSFUNC(getoption(source));
       %let CPSLMENV_source2    = %SYSFUNC(getoption(source2));
       %let CPSLMENV_mprint     = %SYSFUNC(getoption(mprint));
       %let CPSLMENV_mlogic     = %SYSFUNC(getoption(mlogic));
       %let CPSLMENV_macrogen   = %SYSFUNC(getoption(macrogen));
       %let CPSLMENV_symbolgen  = %SYSFUNC(getoption(symbolgen));
       %let CPSLMENV_errorabend = %SYSFUNC(getoption(errorabend));
       %let CPSLMENV_fmtsearch  = %SYSFUNC(getoption(fmtsearch));
   %end;

   %if &SLMDEBUG eq 1 %then %do;
       options notes source source2 mprint;
   %end;
   %else %do;
       options nonotes  nosource   nosource2 nomprint nomacrogen nosymbolgen ;
   %end;

   %let _SLMrc = 0;
   %if %length(&_rc) eq 0 %then %do;
       %local RC;
       %let _rc = RC;
   %end;

   %********************************* ;
   %* Determine host-specific stuff * ;
   %********************************* ;
   %if %cphsttyp eq MVS %then %do;
       %let accessString = %str(disp=shr);
   %end;
   %else %do;
       %let accessString = %str(access=readonly);
   %end;

   %****************** ;
   %* Internal macro * ;
   %****************** ;
   %macro _releaseLib(name);
       %if %sysfunc(libref(&name)) eq 0 %then %do;
           libname &name clear;
       %end;
   %mend _releaseLib;

   %put NOTE:(&SYSMACRONAME)  SLM2000 SAS IT Service Level Management
initialization in progress.;

   %********************************** ;
   %* Validate the ACTION= parameter * ;
   %********************************** ;
   %let _action = %UPCASE(&action);
   %if ((&_action ne START) and
        (&_action ne STOP)) %then %do;
       %let _SLMrc= 8;
       %put ERROR:(&SYSMACRONAME)  SLM2001 Invalid action= parameter
value specified: &action;
       %goto EXIT;
   %end;
   %else %do;
       %let _actionParm = ACTION=&_action;
   %end;

   %if &_action eq STOP %then %do;
       %let _envPathParm = %str();
       %let _slmRootParm = %str();
   %end;
   %else %do;
       %************************************** ;
       %* Massage the SLM environment parm.  * ;
       %* Be sure the pathname is not blank. * ;
       %************************************** ;
   %if (%length(&environmentDBPath) le 0) and
        (%length(&shareService) le 0) %then %do;
       %let _SLMrc = 8;
       %put ERROR:(&SYSMACRONAME)  SLM2002 Parameter EnvironmentDBPath
not specified or zero length.;
       %goto EXIT;
   %end;
   %let _envPathParm = ENVIRONMENT=%str(%'&environmentDBPath%');

   %****************************************;
   %* Add SHARE-related parameters, if any *;
   %****************************************;
   %if (%length(&shareService) gt 0) %then %do;
      %let _shareServiceParm = SHARESERVICE=&shareService;
      %if (%length(&shareUser) gt 0) %then
         %let _shareUserParm = SHAREUSER=%str(%'&shareUser%');
      %if (%length(&sharePassword) gt 0) %then
         %let _sharePasswordParm = SHAREPASSWORD=%str(%'&sharePassword%');
   %end;

       %******************************************* ;
       %* Allocate SLMLIB to access the software. * ;
       %******************************************* ;
       %cpslmlib(slmpath=&slmpath,_rc=_SLMrc);
       %if (&_SLMrc ne 0) %then %do;
           %put ERROR:(&SYSMACRONAME)  SLM2006 Allocation
failed for &slmpath;
           %goto EXIT;
       %end;
   %end;

   %************************************************************* ;
   %* Set the AF DEBUG= parm based upon the setting of SLMDEBUG * ;
   %************************************************************* ;
   %if &slmdebug eq 1 and &SYSENV eq FORE %then %do;
      %let _debugParm = YES;
   %end;
   %else %do;
      %let _debugParm = NO;
   %end;

   %********************************* ;
   %* Turn off confounding windows  * ;
   %********************************* ;
   %if %cphsttyp eq WIN %then %do;
       %local _dmsexp;
       proc sql noprint;
          select setting into :_dmsexp from dictionary.options
             where optname='DMSEXP';  quit;  run;
       %if &_dmsexp eq DMSEXP %then
          %let _windowPrefix =
            %str( ODSRESULTS; CAN; NEXT 'EXPLORER'; CAN; );
       %end;

   %**************************************************** ;
   %* call the SCL code (return code is set in _SLMRC) * ;
   %* (to use SCL Debugger add af before semicolon.    * ;
   %**************************************************** ;
   dm "&_windowPrefix afa c=slmlib.slmenv.slmbatch.scl
       title='IT Service Level Management'
       aws=YES &_actionParm &_envPathParm &_slmrootParm
           &_shareServiceParm &_shareUserParm &_sharePasswordParm
       DEBUG=&_debugParm" afa;

%EXIT:
   %if &_action eq STOP %then %do;
       %_releaseLib(SLM)
       %_releaseLib(SLMLIB)
       %_releaseLib(PGMLIB)
       %_releaseLib(SITELIB)
       %_releaseLib(DETAIL)
       %_releaseLib(DAY)
       %_releaseLib(WEEK)
       %_releaseLib(MONTH)
       %_releaseLib(YEAR)
       %_releaseLib(PDBWORK)
       %_releaseLib(ADMIN)
       %_releaseLib(COLLECT)
       %_releaseLib(DICTLIB)
   %end;

   %******************************************** ;
   %* Populate user return code macro variable * ;
   %******************************************** ;
   %if %length(&_rc) gt 0 %then %do;
       %let &_rc = &_SLMrc;
   %end;
   %put NOTE:(&SYSMACRONAME) ended with return code &_SLMrc;
   %if %upcase(&action) eq STOP %then %do;
       options &CPSLMENV_notes     &CPSLMENV_source &CPSLMENV_source2
               &CPSLMENV_mprint    &CPSLMENV_mlogic &CPSLMENV_macrogen
               &CPSLMENV_symbolgen &CPSLMENV_errorabend
               fmtsearch= &CPSLMENV_fmtsearch           ;

       %*********************************************************** ;
       %* Reset these options so we do not use them inadvertently * ;
       %* in the SLMServerSession object.                         * ;
       %*********************************************************** ;
       %let CPSLMENV_notes      = . ;
       %let CPSLMENV_source     = . ;
       %let CPSLMENV_source2    = . ;
       %let CPSLMENV_mprint     = . ;
       %let CPSLMENV_mlogic     = . ;
       %let CPSLMENV_macrogen   = . ;
       %let CPSLMENV_symbolgen  = . ;
       %let CPSLMENV_errorabend = . ;
       %let CPSLMENV_fmtsearch  = %str() ;
   %end;
%mend CPSLMENV;
