/*+-------------------------------------------------------------------------+
  | Copyright (C) 2003 by SAS Institute Inc., Cary, NC 27512-8000
  | Name:     cpslmind.sas
  | Support:  sxm
  | Product:  SAS IT Service Level Management
  | Language: SAS
  | Usage:
  |    indicator1-10   - the metric to use for this report
  |    desc1-10        - indicator description for title (e.g., Availability)
  |    format1-10      - the format to use for the indicator (e.g., percent8.2)
  |    date            - the date for the report (optional), defaults to
  |                      currently defined report date.  Format should be
  |                      ddmmmyyyy.
  |    node            - the table name to be used for this report
  |    outdir          - the directory where the report should be written.
  |                      Defaults to the main subdirectory
  |
  | Assumes the standard SLM macro variables have been defined for report
  |   location, current report date, etc.
  |
  | Purpose:  Generate daily report for this indicator for all nodes in the
  |           contract.
  |
  | History:  Date    action
  |           08Jul03 Initial Coding                                     sxm
  |           26Aug03 Use actual environmental data                      sxm
  |           05Sep03 Correct calendar to end of month                   sxm
  |           02Oct03 S0222208 Support previous and next date movement   sxm
  |           03Oct03 S0222725 Change directory structure                sxm
  |           18Nov03 S0227918 Change according to new report specs      sxm
  |           04Dec03 S0228611 Fix link to outages report                sxm
  |           17Dec03 S0231512 Use new global macro variables            sxm
  |           20Jan04 S0233071 Handle objectives without targets         sxm
  |           20Jan04 S0234721 Many cosmetic changes                     sxm
  |           20Jan04 S0233060 Remove blank lines in select box          sxm
  |           20Jan04 S0234472 Use default F10.3 format                  sxm
  |           23Jan04 S0233050 Show all components with sparse data      sxm
  |           10Feb04 S0233071 Show 3 month page for first enabled obj   sxm
  |           12Feb04 S0236669 Move footer to t3m page                   sxm
  |           14Sep04 S0257772 Handle case where no objectives enabled   sxm
  |
  | Future:
  | End
  +-------------------------------------------------------------------------+*/

/* TODO:  Get statistics from contract definition */

%macro cpslmind(adesc=,  aformat=,  aflag=Y,
                rdesc=,  rformat=,  rflag=Y,
                tdesc=,  tformat=,  tflag=Y,
                cdesc=,  cformat=,  cflag=Y,
                node=, date=, outdir=);

%if %quote(&adesc) = %quote()
    %then %let adesc=Availability;
%if %quote(&rdesc) = %quote()
    %then %let rdesc=Response Time;
%if %quote(&tdesc) = %quote()
    %then %let tdesc=Throughput;
%if %quote(&cdesc) = %quote()
    %then %let zdesc=Composite;
    %else %let zdesc=&cdesc;
%let zformat=&cformat;
%let zflag=&cflag;

%if %quote(&aformat) = %quote()
    %then %let aformat=f10.3;
%if %quote(&rformat) = %quote()
    %then %let rformat=f10.3;
%if %quote(&tformat) = %quote()
    %then %let tformat=f10.3;
%if %quote(&zformat) = %quote()
    %then %let zformat=f10.3;

%if %str(&date) ne %str() %then %do;
data _null_;
     date = "&date"d;
     call symput("RPTDATE", put(date, date9.));
     call symput('RPTDAY', put(day(date),z2.));
     call symput('RPTMONTH', put(month(date),z2.));
     call symput('RPTYEAR', put(year(date),4.));
     call symput('RPTYEAR2', put(mod(year(date),100),z2.));
     call symput('TEXTDATE', put(date,worddate20.));
     run;
%end;

proc format;
     value $symbols 'GE' = '&ge;'
                     'GT' = '&gt;'
                     'LE' = '&le;'
                     'LT' = '&lt;'
                     'EQ' = '=';
     run;

%let cpsep=%cpsep();

data _null_;
     calbegin = mdy(&rptmonth, 1, &rptyear);
     calend   = intnx('month', calbegin, 0, 'end');
     call symput('CALBEGIN',put(calbegin,date9.));
     call symput('CALEND',put(calend,date9.));
     stop;
     run;

%if %bquote(&outdir) = %quote()
    %then %let outdir = %quote(&cpslmcrp);

 data _null_;
      set admin.contractStructure;
      where tablename="&node";
      call symput("NODENAME",trim(name));
      call symput("AGRMENT",trim(agreement));
      run;

 data work.nodeday;
      set day.&node (where=(date="&date"d));
      run;

 filename tempcode catalog "work.test.t3m&node..source";
 data _null_;

      /* write main page */
      length filename $ 100;
      filename = "&outdir&node&cpsep.ai&rptyear2&rptmonth&rptday..htm" ;
      file html filevar=filename;
      retain wday wholerow 0 enddate "&calend"d date "&date"d;
      retain selnode "&node";
      year = year(enddate);
      month = month(enddate);
      %cpslmhdr();
      %cpslmenu(
      dlink=%str(javascript:menulink(%'&rptyear2&rptmonth&rptday..htm%'));,
          mlink=%str(javascript:menulink(%'mtd&rptyear2&rptmonth..htm%'));,
          ylink=%str(javascript:menulink(%'ytd&rptyear..htm%');));
      prevdate = "&date"d-1;
      nextdate = "&date"d+1;
      put '<table width="100%" class="smaller">' /
          '<tr><td align="left" width="15%">&nbsp;' /
          '<script language="Javascript">' /
          "prevControl(""&rptyear2&rptmonth&rptday"","
          '"' "javascript:datelink('"
          prevdate yymmdd6. '.htm'');", "<< Previous Day");' /
          '</script>' /
          '</td><td align="right" width="15%">&nbsp;' /
          '<script language="Javascript">' /
          "nextControl(""&rptyear2&rptmonth&rptday"","
          '"' "javascript:datelink('"
           nextdate yymmdd6. '.htm'');", "Next Day >>");' /
          '</script>' /
          '</td></tr></table>' /
          '<div style="position: relative; top: 10; left: 10;">' /
          '<table class="heading">' /
          '<tr><td>Type of Report:</td><td>Daily and Trend</td></tr>' /
          "<tr><td>Report for Date:</td><td>&rptdate</td></tr>" /
          '</table>' / '<p>' /
          '<table width="100%"><tr><td  width="25%">' /
          '<script language="JavaScript">' /
          'var abbr = "a";' /
          'function setNode(s)' /
          '{' /
          '   var node = s.options[s.selectedIndex].value;' /
          '   parent.document.location = "../" + node '
          " + ""/ai&rptyear2&rptmonth&rptday..htm"";" /
          '}' /
          'function menulink(base) ' /
          '{' /
          '   parent.document.location= "../main/" + abbr + base; ' /
          '}' /
          'function datelink(base) ' /
          '{' /
          '   parent.document.location= "ai"+ base; ' /
          '}' /
          'function setObj(s)' /
          '{' /
          '  abbr = s.options[s.selectedIndex].value; ' /
          "  top.t3month.location.href=abbr "
             "+ ""t3m&rptyear2&rptmonth..htm""; " /
          '}' /
          '</script>' /
          '<b>Select a Contract Node:</b><br>' /
          '<select onchange="setNode(this);" size="12">' ;
      do i = 1 to envobs;
         set admin.contractStructure point=i nobs=envobs;
         length indent $ 90;
         if tablename = selnode then selected = " SELECTED";
            else selected = "";
         retain tab '&nbsp;&nbsp;&nbsp;';
         indent =" ";
         if level = 1 then indent = tab;
            else if level > 1
                 then indent = repeat(tab, level-1);
         put '<option value="' tablename +(-1)'"' selected '>'
             indent name ;
      end;
      put '</select>' /
          '</td><td align="center">' ;

      if gotdata=0 then do;
         put '<font size="200%">' /
             '<style>' /
             'th { text-align: center;}' /
             '</style>' /
             '<table width="60%" bordercolor="#CFCBB1" cellspacing="0" '
             'border="1">' /
             "<tr><th>&nodename</th></tr>" /
             '<tr><td>No data for this node for this date.</td></tr>' /
             '</table>' / '</tr>' / '</table>' / '<p>' /
             '<div class="menubar">' ;
          %cpslmft;
          put '</div>' /
              '</body></html>';
      end;
      set work.nodeday nobs=gotdata;
      tablename = selnode;
      set admin.contractStructure key=tablename;

      array targets(*) atarget rtarget ttarget ztarget;
      array tgtbas(*) atgtbas rtgtbas ttgtbas ztgtbas;
      array scores(*) ascore rscore tscore zscore;
      array indicators(*) asli rsli tsli zsli;
      array colors(*) acolor rcolor tcolor zcolor;
      array units(*) $ 40 aunits runits tunits zunits;
      array enabled(*) $1 aenabled renabled tenabled zenabled;
      array objactive(*) aobjactive robjactive tobjactive zobjactive;
      array operators(*) aoperator roperator toperator zoperator;
      array targetlabels(4)  $ 15 _temporary_
                 ("&adesc","&rdesc","&tdesc","&zdesc");
      array abbreviations(4) $ 1 ('a','r','t','z');

      activeobjs = 0;
      do i = 1 to dim(objactive);
         if objactive(i) = 'Y' then activeobjs+1;
      end;
      if activeobjs=0 then do;
         put '<font size="200%">' /
             '<style>' /
             'th { text-align: center;}' /
             '</style>' /
             '<table width="60%" bordercolor="#CFCBB1" cellspacing="0" '
             'border="1">' /
             "<tr><th>&nodename</th></tr>" /
             '<tr><td>No objectives are active for this node.</td></tr>' /
             '</table>' / '</tr>' / '</table>' / '<p>' /
             '<div class="menubar">' ;
          %cpslmft;
          put '</div>' /
              '</body></html>';
          stop;
      end;


      put '<font size="200%">' /
          '<style>' /
          'th    {  text-align: center;}' /
          '</style>' /
          '<table width="80%" bordercolor="#CFCBB1" cellspacing="0" '
             'border="1">' /
          "<tr><th colspan=""5"">&nodename</th></tr>" /
          '<tr><th>&nbsp;</th>' /
          '    <th>Actual<br>Value</th>' /
          '    <th>Current<br>Target</th>' /
          '    <th>Actual<br>Score</th>' /
          '    </tr>' ;

      firstobj = ' ';

      do i = 1 to dim(objactive);
         if objactive(i) ='Y' then do;
            if firstobj = ' ' then firstobj = abbreviations(i);
            if colors(i) ne ' '
               then colortext = 'bgcolor="#' !! colors(i) !! '"';
               else colortext = ' ';
            length tname $ 8;
            call vname(targets(i),tname);
            abbr = substr(left(tname),1,1);
            if tgtbas(i) = 'SLI' then targetbase = 'Indicator';
               else targetbase = 'Score';
            put '<tr><th style="text-align:left;">' targetlabels(i) '</td>'
                '    <td ' colortext ' align="right">' indicators(i) f8.3
                     '</td>' ;
            if targets(i) ne . then put
                '    <td align="right">' targetbase operators(i) $symbols.
                     targets(i) units(i) '</td>';
               else put '<td align="right">.</td>';
            put '    <td align="right">' scores(i) '</td>' /
                '    </tr>' ;
         end;
      end;
      put '</table>' /
          '</tr></table>';
      put '<div color="#F1EACB">' / '<hr>' / '<p>' / '</div>';
      put '<h3>3 Month View of Objective Type:' /
          '<select onChange="setObj(this)">' ;
      do i = 1 to dim(targets);
         if objactive(i) = 'Y' then do;
            put '<option value="' abbreviations(i) $char1. '">'
                targetlabels(i);
         end;
      end;
      put '</select>';

      put '<iframe name="t3month" border="0" frameborder="0" width="100%"' /
          '   height="100%" src="'
          firstobj $char1. "t3m&rptyear2&rptmonth..htm"">" /
          '</iframe>' /
          '</body></html>';

      file tempcode;
      array metrics(4) $1 _temporary_ ('a','r','t','z');
      do i=1 to dim(objactive);
         if objactive(i)='Y' then put
            '%cpslmt3m(node=' tablename ',date=' date date9.
                  ',metric=' metrics(i)  ');';
      end;

      stop;
 run;
 %inc tempcode;
%mend cpslmind;
